@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *
  *   Class implementation of the approximate search algorithm
@@ -12,7 +12,9 @@
 #include "cb2bib_utilities.h"
 #include "triads.h"
 
-#if QT_VERSION >= 0x050400
+namespace
+{
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)) && (QT_VERSION < QT_VERSION_CHECK(5, 12, 0))
 static const QRegularExpression::PatternOptions _qre_pattern_options(QRegularExpression::DontCaptureOption |
         QRegularExpression::UseUnicodePropertiesOption |
         QRegularExpression::OptimizeOnFirstUsageOption);
@@ -20,6 +22,7 @@ static const QRegularExpression::PatternOptions _qre_pattern_options(QRegularExp
 static const QRegularExpression::PatternOptions _qre_pattern_options(QRegularExpression::DontCaptureOption |
         QRegularExpression::UseUnicodePropertiesOption);
 #endif
+} // namespace
 
 
 approximatePattern::approximatePattern() : compositePattern() {}
@@ -33,7 +36,8 @@ approximatePattern::approximatePattern(const QString& pattern, const Qt::CaseSen
 
 void approximatePattern::setPattern(const QString& pattern, const Qt::CaseSensitivity cs)
 {
-    _string = pattern.simplified();
+    _string = pattern;
+    _subpatterns = pattern.split(c2bUtils::nonLetter, QString::SkipEmptyParts);
     _case_sensitivity = cs;
     _is_multipattern = false;
     _matched_length = -1;
@@ -60,6 +64,12 @@ void approximatePattern::setPattern(const QString& pattern, const Qt::CaseSensit
     {
         _regexp.setPattern(wordPattern(_string, _case_sensitivity));
         _regexp.setPatternOptions(_qre_pattern_options);
+        // Avoid rare cases triggering 'too large regular expression' by just composing prefix and suffix
+        if (!_regexp.isValid())
+        {
+            _regexp.setPattern("(?:" + _string_pieces.join('|') + ')');
+            _regexp.setPatternOptions(_qre_pattern_options);
+        }
         return;
     }
     _is_multipattern = true;
@@ -69,7 +79,7 @@ void approximatePattern::setPattern(const QString& pattern, const Qt::CaseSensit
     const double scan_factor(100. / percent_scan);
     const int max_blocks(_string_pieces.count() / 2);
     const int requested_blocks(c2bUtils::nearInteger(scan_factor));
-    const int blocks(qMin(max_blocks, 1 + requested_blocks));
+    const int blocks(std::min(max_blocks, 1 + requested_blocks));
     int pieces_per_block(_string_pieces.count() / blocks); // Ceiling
     if ((_string_pieces.count() % blocks) > 0)
         ++pieces_per_block;
@@ -228,10 +238,10 @@ const QStringList approximatePattern::splitWord(const QString& word) const
         slen_min = 0;
 
     w = word;
-    const int wlenMp_min(qMax(plen_min, wlen - slen_min));
-    const int wlenMs_min(qMax(slen_min, wlen - plen_min));
-    const int wlenMp_max(qMax(plen_max, wlen - slen_max));
-    const int wlenMs_max(qMax(slen_max, wlen - plen_max));
+    const int wlenMp_min(std::max(plen_min, wlen - slen_min));
+    const int wlenMs_min(std::max(slen_min, wlen - plen_min));
+    const int wlenMp_max(std::max(plen_max, wlen - slen_max));
+    const int wlenMs_max(std::max(slen_max, wlen - plen_max));
 #if C2B_DEBUG_APPROXIMATEPATTERN
     qDebug() << wlenMp_min << wlenMs_min << w.left(wlenMp_min) << w.right(wlenMs_min);
     qDebug() << wlenMp_max << wlenMs_max << w.left(wlenMp_max) << w.right(wlenMs_max);
@@ -270,8 +280,8 @@ int approximatePattern::stretch(int piece_i, int piece_j) const
     const int minStretch(3);
     const int maxStretch(20);
     if (_string_pieces.at(piece_j).length() > 4)
-        return qMax((maxStretch * (piece_j - piece_i)),
-                    minStretch * (_piece_starts.at(piece_j) - _piece_ends.at(piece_i)));
+        return std::max((maxStretch * (piece_j - piece_i)),
+                        minStretch * (_piece_starts.at(piece_j) - _piece_ends.at(piece_i)));
     else
         return minStretch * (_piece_starts.at(piece_j) - _piece_ends.at(piece_i)); // Estimated error ratio only
 }
