@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *
  *   Class implementation of the approximate search algorithm
@@ -69,6 +69,10 @@ public:
     {
         return _submatchers;
     }
+    inline const QStringList& subpatternStrings() const
+    {
+        return _subpatterns;
+    }
 
 
 private:
@@ -84,6 +88,7 @@ private:
     QList<int> _piece_starts;
     QStringList _prefixes;
     QStringList _string_pieces;
+    QStringList _subpatterns;
     QStringList _suffixes;
     QVector<substringMatcher> _submatchers;
     mutable QRegularExpressionMatch _regexp_match;
