@@ -1,13 +1,12 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bibParser.h"
 
 #include "arxivXml.h"
-#include "authorString.h"
 #include "bibPreparser.h"
 #include "crJson.h"
 #include "document.h"
@@ -57,7 +56,7 @@ bibParser::~bibParser()
 QString bibParser::parse(const QString& field, const QString& value, const QString& init_value)
 {
     QString v(value);
-    if (field == "file")
+    if (field == QLatin1String("file"))
         return v.trimmed();
     if (field == "abstract")
         document::normalize(v, document::Complete);
@@ -65,12 +64,12 @@ QString bibParser::parse(const QString& field, const QString& value, const QStri
     if (v.isEmpty())
         return v;
     c2bUtils::fullBibToC2b(v);
-    if (field == "author")
+    if (field == QLatin1String("author"))
     {
         c2bUtils::debug(v);
         v = _authorString.toBibTeX(v, _settingsP->value("cb2Bib/UseFullNames").toBool());
     }
-    else if (field == "addauthors")
+    else if (field == QLatin1String("addauthors"))
     {
         c2bUtils::debug(v);
         if (init_value.isEmpty())
@@ -78,13 +77,13 @@ QString bibParser::parse(const QString& field, const QString& value, const QStri
         else
             v = init_value + " and " + _authorString.toBibTeX(v, _settingsP->value("cb2Bib/UseFullNames").toBool());
     }
-    else if (field == "editor")
+    else if (field == QLatin1String("editor"))
     {
         c2bUtils::debug(v);
         v.remove(QRegExp("\\((Editor|Editors|Ed|Eds)\\.{0,1}\\)", Qt::CaseInsensitive));
         v = _authorString.toBibTeX(v, _settingsP->value("cb2Bib/UseFullNames").toBool());
     }
-    else if (field == "addeditors")
+    else if (field == QLatin1String("addeditors"))
     {
         c2bUtils::debug(v);
         v.remove(QRegExp("\\((Editor|Editors|Ed|Eds)\\.{0,1}\\)", Qt::CaseInsensitive));
@@ -93,24 +92,28 @@ QString bibParser::parse(const QString& field, const QString& value, const QStri
         else
             v = init_value + " and " + _authorString.toBibTeX(v, _settingsP->value("cb2Bib/UseFullNames").toBool());
     }
-    else if (field == "doi")
+    else if (field == QLatin1String("doi"))
+    {
         v.remove(QRegExp("^.+(?=10\\.[\\d\\.]+/\\S+)"));
-    else if (field == "url")
+        if (v.endsWith(QLatin1Char('.')) || v.endsWith(QLatin1Char(',')) || v.endsWith(QLatin1Char(';')))
+            v.chop(1);
+    }
+    else if (field == QLatin1String("url"))
     {
         // Remove redundant DOI URLs
         if (v.contains("doi.org/10."))
             v.clear();
     }
-    else if (field == "isbn")
+    else if (field == QLatin1String("isbn"))
         v.remove(' ');
-    else if (field == "journal")
+    else if (field == QLatin1String("journal"))
     {
         if (_settingsP->value("cb2Bib/SetJournalsToFullname").toBool())
             v = fullJournal(v);
         else
             v = abbreviatedJournal(v);
     }
-    else if (field == "keywords")
+    else if (field == QLatin1String("keywords"))
     {
         v.replace(" - ", ",");
         QStringList kl(v.split(QRegExp("[^\\w\\s-']"), QString::SkipEmptyParts));
@@ -120,29 +123,29 @@ QString bibParser::parse(const QString& field, const QString& value, const QStri
         v.replace(QRegExp("\\s+,"), ",");
         v = v.toLower();
     }
-    else if (field == "month")
+    else if (field == QLatin1String("month"))
         v = _month_dbP->retrieve(v);
     // Fields edition and note require first letter capitalization
-    else if (field == "edition")
+    else if (field == QLatin1String("edition"))
         v = c2bUtils::setCapitalization(v);
-    else if (field == "note")
+    else if (field == QLatin1String("note"))
         v = c2bUtils::setCapitalization(v);
     // Process pages, volume, number, and year to set hyphenation
-    else if (field == "pages")
+    else if (field == QLatin1String("pages"))
         v = adjacentNumbers(v);
-    else if (field == "volume")
+    else if (field == QLatin1String("volume"))
         v = adjacentNumbers(v);
-    else if (field == "number")
+    else if (field == QLatin1String("number"))
         v = adjacentNumbers(v);
-    else if (field == "year")
+    else if (field == QLatin1String("year"))
         v = adjacentNumbers(v);
-    else if (field == "title" || field == "booktitle")
+    else if (field == QLatin1String("title") || field == QLatin1String("booktitle"))
         v = c2bUtils::setCapitalization(v);
-    else if (field == "addtitle")
+    else if (field == QLatin1String("addtitle"))
     {
-        v = c2bUtils::setCapitalization(v);
         if (!init_value.isEmpty())
-            v = init_value + ": " + v;
+            v = init_value + QLatin1String(": ") + v;
+        v = c2bUtils::setCapitalization(v);
     }
     return c2bUtils::simplifyString(v);
 }
@@ -239,7 +242,7 @@ QString bibParser::excerpt(const QString& text, const QStringList& hints) const
     txt = c2bUtils::simplifyString(txt);
     const QStringList txtlist(txt.split(' ', QString::SkipEmptyParts));
     QStringList txtlistSimp;
-    for (int i = 0; i < qMin(15, txtlist.count()); ++i)
+    for (int i = 0; i < std::min(15, txtlist.count()); ++i)
         txtlistSimp.append(txtlist.at(i));
     return txtlistSimp.join(" ");
 }
@@ -468,7 +471,7 @@ void bibParser::parse(const QString& text, QString* out_text, QString* out_tagte
                 _current_reference["abstract"] = parse("abstract", value);
             else if (tag == "FAU")
                 _current_reference["author"] =
-                    parse("addauthors", author::fromMedline(value), _current_reference.value("author"));
+                    parse("addauthors", authorFromMedline(value), _current_reference.value("author"));
             else if (tag == "TA")
                 _current_reference["journal"] = parse("journal", value);
             else if (tag == "IP")
