@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bibSearcher.h"
@@ -20,9 +20,9 @@
   \htmlonly
   <a href="https://arxiv.org/abs/0705.0751" target="_blank">approximate strings</a>,
   \endhtmlonly
-  strings, regular expressions, or wildcard filters. Patterns admit Unicode
-  characters. The scope of each pattern can be the reference as a whole or be
-  focused on a particular reference field. The fields <tt>year</tt>,
+  strings, contexts, regular expressions, or wildcard filters. Patterns admit
+  Unicode characters. The scope of each pattern can be the reference as a whole
+  or be focused on a particular reference field. The fields <tt>year</tt>,
   <tt>file</tt>, and <tt>journal</tt> are treated specifically. The field
   <tt>year</tt> has the qualifiers <tt>Exact</tt>, <tt>Newer</tt>, and
   <tt>Older</tt>. The field <tt>file</tt> can optionally refer to either the
@@ -50,21 +50,73 @@
   references. This permits, for instance, for the pattern 'M&#248;ller' to
   retrieve either 'M&#248;ller' or 'M{\o}ller', without regard to how the
   BibTeX reference is written. By checking <b>Simplify source</b>, the
-  reference and the converted PDF files are simplified to plain Ascii. Thus,
-  the pattern '\bMoller\b' will hit any of 'M&#248;ller', 'M{\o}ller', or
+  reference and the converted PDF files are simplified to plain ASCII. In this
+  way, the pattern '\bMoller\b' will hit any of 'M&#248;ller', 'M{\o}ller', or
   'Moller'. Additionally, all non-word characters are removed, preserving only
-  the Ascii, word structure of the source. Note that source simplification is
+  the ASCII, word structure of the source. Note that source simplification is
   only performed for the patterns whose scope is <tt>all</tt> or <tt>file</tt>
   contents, and that and so far, cb2Bib has only a subset of such conversions.
   Implemented TeX to Unicode conversions can be easily checked by entering a
-  reference. The Unicode to Ascii letter-only conversion, on the other hand, is
+  reference. The Unicode to ASCII letter-only conversion, on the other hand, is
   the one that cb2Bib also uses to write the reference IDs and, hence, the
-  renaming of dropped files. cb2Bib can also understand minor sub and
-  superscript formatting. For instance, the pattern 'H2O' will retrieve
-  'H<sub>2</sub>O' from a BibTeX string <code>H$_{2}$O</code>.
+  renaming of dropped files. cb2Bib can understand minor sub and superscript
+  formatting. For instance, the pattern 'H2O' will retrieve 'H<sub>2</sub>O'
+  from a BibTeX string <code>H$_{2}$O</code>.
   \endhtmlonly
 
 
+\section contextsearch Contextual Search
+
+  A convenient way to retrieve documents is by matching a set of keywords
+  appearing in a close proximity context, while disregarding the order in which
+  the words might had been written. cb2Bib considers two types of contextual
+  searches. One flexibilizes phrase matching only at the level of the
+  constituting words. It is accessed by selecting <tt>Fixed string:
+  Context</tt> in the pattern type box. The other one, in addition, stems the
+  supplied keywords. It is accessed by selecting <tt>Context</tt>. By way of
+  stemming, the keyword <i>analyze</i>, for example, will also match
+  <i>analyse</i>, and <i>aluminum</i> will match <i>aluminium</i> too.
+
+
+  The syntax for <tt>Context</tt> type patterns is summarized in the following
+  table:
+
+\verbatim
+
+
+Operator   Example                          Expansion
+
+space      contextual search                contextual AND search
+
+|          contextual search|matching       contextual AND (search|match)
+
++          contextual search|+matching      contextual AND (search|\bmatching\b)
+
+_          contextual_search                contextual.{0,25}search
+
+-          non-parametric                   non.{0,1}parametr
+
+
+Diacritics and Greek letters:
+
+           naïve search                     (naïve|naive) AND search
+
+           kendall tau                      kendall AND (tau|τ)
+
+
+\endverbatim
+
+  In the above examples, operator space <tt>AND</tt> means match words in any
+  order. Operator <tt>_</tt> preserves word order, and operator <tt>+</tt>
+  prevents stemming and forces exact word match. Operator <tt>-</tt> considers
+  cases of words that might had been written either united, hyphenated, or
+  space separated. Diacritics are expanded if the diacritic mark is specified.
+  This is, <i>naive</i> will not match <i>naïve</i>. On the other hand, Greek
+  letters are expanded only when typed by name.
+
+
+
+
 \section notes Notes
 
   - cb2Bib uses an internal cache to speed up the search of linked files.
@@ -88,7 +140,8 @@
 /**
     Top level driver for searching BibTeX files
 */
-bibSearcher::bibSearcher(bibParser* bp, QObject* parento) : QObject(parento), _bpP(bp), _do_search_similar(false)
+bibSearcher::bibSearcher(bibParser* bp, QObject* parento)
+    : QObject(parento), _bpP(bp), _do_rank_results(true), _do_search_similar(false)
 {
     clear();
 }
@@ -98,22 +151,23 @@ bibSearcher::bibSearcher(bibParser* bp, QObject* parento) : QObject(parento), _b
     searching repeated or similar references.
 */
 bibSearcher::bibSearcher(bibParser* bp, const QString& bib_dir, QObject* parento)
-    : QObject(parento), _bpP(bp), _do_search_similar(true)
+    : QObject(parento), _bpP(bp), _do_rank_results(false), _do_search_similar(true)
 {
-    // Retrieve (any_author(approximate) AND any_title(approximate)) OR citeidName(exact)
+    // Retrieve (any_author(context) AND any_title(approximate)) OR citeidName(exact)
     clear();
     setSearchScope(bib_dir, bib_dir, true, false);
     setSimplifySource(false);
     setBoolean(true);
-    const QString type(searchPattern::type(searchPattern::ApproximateString));
-    addPattern(false, false, type, "all", QChar(), _bpP->currentReference().anyAuthor());
-    addPattern(false, false, type, "all", QChar(), _bpP->currentReference().anyTitle());
+    addPattern(false, false, searchPattern::type(searchPattern::Context), QLatin1String("all"), QChar(),
+               _bpP->currentReference().anyAuthor());
+    addPattern(false, false, searchPattern::type(searchPattern::ApproximateString), QLatin1String("all"), QChar(),
+               _bpP->currentReference().anyTitle());
     _do_search_similar_citeid = _bpP->currentReference().citeidName;
     if (_do_search_similar_citeid.isEmpty())
-        _do_search_similar_citeid = '@';
+        _do_search_similar_citeid = QLatin1Char('@');
 }
 
-bibSearcher::bibSearcher() : _bpP(0), _do_search_similar(false)
+bibSearcher::bibSearcher() : _bpP(0), _do_rank_results(false), _do_search_similar(false)
 {
     clear();
 }
@@ -133,17 +187,18 @@ void bibSearcher::exec()
 {
     if (_patterns.count() == 0 && !_do_search_similar)
         return;
-    qSort(_patterns);
-    _include_documents = _include_documents && (_scopes.contains("all") || _scopes.contains("file"));
-    if (_include_documents && !_scopes.contains("file"))
-        _scopes.append("file");
-    _scopes.removeAll("all");
+    std::sort(_patterns.begin(), _patterns.end());
+    _include_documents =
+        _include_documents && (_scopes.contains(QLatin1String("all")) || _scopes.contains(QLatin1String("file")));
+    if (_include_documents && !_scopes.contains(QLatin1String("file")))
+        _scopes.append(QLatin1String("file"));
+    _scopes.removeAll(QLatin1String("all"));
 
     QString and_or;
     if (_boolean_and)
-        and_or = ".AND.";
+        and_or = QLatin1String(".AND.");
     else
-        and_or = ".OR.";
+        and_or = QLatin1String(".OR.");
     for (int i = 0; i < _patterns.count(); ++i)
     {
         const searchPattern& pattern = _patterns.at(i);
@@ -171,10 +226,16 @@ void bibSearcher::exec()
                    .arg(_document_counter);
     if (_include_documents)
         _documents.unload();
-    if (_hits_map.count() == 0)
+    if (_result_references.count() == 0)
         return;
-    _hits_string = "\n\n" + QStringList(_hits_map.keys()).join("\n\n") + "\n\n";
-    _log_string += tr("% Total Unique Hits: %1\n").arg(_hits_map.count());
+    if (_do_rank_results)
+        quadrupleSortDescending(&_result_scores, &_result_references, &_result_html_data, &_result_html_abstracts);
+    _result_string = "\n\n" + _result_references.join("\n\n") + "\n\n";
+    _log_string += tr("% Total Unique Hits: %1\n").arg(_result_references.count());
+#ifdef C2B_DEBUG_SEARCHING
+    if (_result_scores.count() > 0)
+        qDebug() << "Scores: " << _result_scores;
+#endif
 }
 
 QString bibSearcher::searchDocumentKeyword(const QString& bibtexfn, const QString& documentfn, const QString& keyword)
@@ -188,7 +249,8 @@ QString bibSearcher::searchDocumentKeyword(const QString& bibtexfn, const QStrin
         p.replace(QRegExp("\\W"), ".{0,5}");
         p.replace("s", ".?");
         p = "\\b" + p + "\\w*\\b";
-        bs.addPattern(false, false, searchPattern::type(searchPattern::RegularExpression), "all", QChar(), p);
+        bs.addPattern(false, false, searchPattern::type(searchPattern::RegularExpression), QLatin1String("all"),
+                      QChar(), p);
         QString document(bs._documents.current().text());
         c2bUtils::stripDiacritics(document);
         if (bs._patterns.at(0).matches(document))
@@ -218,12 +280,17 @@ void bibSearcher::clear()
     _do_search_similar_citeid.clear();
     _document_counter = 0;
     _error_counter = 0;
-    _hits_map.clear();
-    _hits_string.clear();
     _include_documents = false;
     _log_string = "% cb2Bib " + C2B_VERSION + " / BibTeX Search Log\n";
     _patterns.clear();
     _reference_counter = 0;
+    _reference_match_counter = 0;
+    _reference_score = double(0);
+    _result_html_abstracts.clear();
+    _result_html_data.clear();
+    _result_references.clear();
+    _result_scores.clear();
+    _result_string.clear();
     _scopes.clear();
     _simplify_source = false;
 }
@@ -253,7 +320,7 @@ void bibSearcher::search(const QString& bib_file)
             _documents.load(bib_file, documentContents::Complete);
     }
 
-    const int hits(_hits_map.count());
+    const int hits(_result_references.count());
     bibReference ref;
     _bpP->initReferenceParsing(bib_file, _scopes, &ref);
     while (_bpP->referencesIn(bib_file_contents, &ref))
@@ -267,14 +334,14 @@ void bibSearcher::search(const QString& bib_file)
         if (_aborted)
             return;
     }
-    _log_string += tr("% File %1. Hits: %2\n").arg(bib_file.trimmed()).arg(_hits_map.count() - hits);
+    _log_string += tr("% File %1. Hits: %2\n").arg(bib_file.trimmed()).arg(_result_references.count() - hits);
 }
 
 void bibSearcher::searchReference(const QString& bib_file, const bibReference& ref)
 {
     const bool include_document(
         _include_documents &&
-        _documents.setCurrent(ref.value("file"), &_document_counter, &_log_string, &_error_counter));
+        _documents.setCurrent(ref.value(QLatin1String("file")), &_document_counter, &_log_string, &_error_counter));
 
     // Initialize composite search
     bool hit(_boolean_and);
@@ -282,22 +349,22 @@ void bibSearcher::searchReference(const QString& bib_file, const bibReference& r
     // Composite search
     for (int i = 0; i < _patterns.count(); ++i)
     {
-        const searchPattern& pattern = _patterns.at(i);
-        const searchPattern::modifiers& modifier = pattern.modifier();
+        const searchPattern& pattern(_patterns.at(i));
+        const searchPattern::modifiers& modifier(pattern.modifier());
         bool ihit(false);
 
-        if (modifier.scope == "year")
+        if (modifier.scope == QLatin1String("year"))
         {
             int istr(ref.value(modifier.scope).toInt());
             int jstr(modifier.string.toInt());
-            if (modifier.yearScope == '=')
+            if (modifier.yearScope == QLatin1Char('='))
                 ihit = istr == jstr;
-            else if (modifier.yearScope == '>')
+            else if (modifier.yearScope == QLatin1Char('>'))
                 ihit = istr >= jstr;
-            else if (modifier.yearScope == '<')
+            else if (modifier.yearScope == QLatin1Char('<'))
                 ihit = istr <= jstr;
         }
-        else if (modifier.scope == "all")
+        else if (modifier.scope == QLatin1String("all"))
         {
             if (_simplify_source)
                 ihit = pattern.matches(c2bUtils::toAscii(ref.unicodeReference, c2bUtils::FromBibTeX));
@@ -307,14 +374,14 @@ void bibSearcher::searchReference(const QString& bib_file, const bibReference& r
                 if (include_document)
                     ihit = pattern.matches(_documents.current());
         }
-        else if (modifier.scope == "journal")
+        else if (modifier.scope == QLatin1String("journal"))
         {
             const QString pattern_full(_bpP->fullJournal(modifier.string));
             const QString j_orig(ref.value(modifier.scope));
             const QString j_full(_bpP->fullJournal(j_orig));
             ihit = j_full == pattern_full || pattern.matches(j_orig) || pattern.matches(j_full);
         }
-        else if (modifier.scope == "file" && include_document)
+        else if (modifier.scope == QLatin1String("file") && include_document)
             ihit = pattern.matches(_documents.current());
         else
             ihit = pattern.matches(ref.value(modifier.scope));
@@ -335,12 +402,29 @@ void bibSearcher::searchReference(const QString& bib_file, const bibReference& r
         }
     }
     if (hit)
-        if (!_hits_map.contains(ref.rawReference))
+        if (!_result_references.contains(ref.rawReference))
         {
-            if (include_document)
-                _hits_map.insert(ref.rawReference, location(bib_file, ref) + excerpts(_documents.current().text()));
+            _result_references.append(ref.rawReference);
+            _reference_score = double(0);
+            _reference_match_counter = 0;
+            if (_scopes.contains(QLatin1String("title")))
+                setTitleRank(ref.value(QLatin1String("title")));
+            else if (_scopes.contains(QLatin1String("booktitle")))
+                setTitleRank(ref.value(QLatin1String("booktitle")));
+            if (_scopes.contains(QLatin1String("abstract")))
+                _result_html_abstracts.append(highlight(ref.value(QLatin1String("abstract"))));
             else
-                _hits_map.insert(ref.rawReference, location(bib_file, ref));
+                _result_html_abstracts.append(highlight(_bpP->singleReferenceField(QLatin1String("abstract"), ref)));
+            if (include_document)
+                _result_html_data.append(location(bib_file, ref) + excerpts(_documents.current().text()));
+            else
+                _result_html_data.append(location(bib_file, ref));
+            _result_scores.append(_reference_score);
+#if C2B_DEBUG_SCORER
+            _debug_scorer_scores.append(_reference_score);
+            _debug_scorer_occurrences.append(_reference_match_counter);
+            _debug_scorer_documents.append(_bpP->singleReferenceField(QLatin1String("title"), ref));
+#endif
         }
 }
 
@@ -348,8 +432,11 @@ void bibSearcher::searchSimilarReferences(const QString& bib_file, const bibRefe
 {
     if (ref.citeidName == _do_search_similar_citeid)
     {
-        if (!_hits_map.contains(ref.rawReference))
-            _hits_map.insert(ref.rawReference, location(bib_file, ref));
+        if (!_result_references.contains(ref.rawReference))
+        {
+            _result_references.append(ref.rawReference);
+            _result_html_data.append(location(bib_file, ref));
+        }
         return;
     }
     if (_patterns.count() == 0)
@@ -361,29 +448,60 @@ void bibSearcher::searchSimilarReferences(const QString& bib_file, const bibRefe
     // Composite search
     for (int i = 0; i < _patterns.count(); ++i)
     {
-        const searchPattern& pattern = _patterns.at(i);
+        const searchPattern& pattern(_patterns.at(i));
         hit = hit && pattern.matches(ref.unicodeReference);
         if (!hit)
             break;
     }
     if (hit)
-        if (!_hits_map.contains(ref.rawReference))
-            _hits_map.insert(ref.rawReference, location(bib_file, ref));
+        if (!_result_references.contains(ref.rawReference))
+        {
+            _result_references.append(ref.rawReference);
+            _result_html_data.append(location(bib_file, ref));
+        }
 }
 
-const QString bibSearcher::excerpts(const QString& contents) const
+void bibSearcher::setTitleRank(const QString& title)
+{
+    if (!_do_rank_results || title.isEmpty())
+        return;
+    for (int i = 0; i < _patterns.count(); ++i)
+    {
+        const searchPattern& pattern(_patterns.at(i));
+        const searchPattern::modifiers& modifier(pattern.modifier());
+        pattern.initializeScores();
+        if (modifier.NOT)
+            continue;
+        if (modifier.scope != QLatin1String("title") && modifier.scope != QLatin1String("booktitle"))
+            continue;
+        int pos(0);
+        while (pos >= 0)
+        {
+            pos = pattern.indexIn(title, pos);
+            if (pos > -1)
+            {
+                pattern.updateScore();
+                pos += pattern.matchedLength();
+            }
+        }
+        _reference_score += 10 * pattern.matchedScore();
+    }
+}
+
+QString bibSearcher::excerpts(const QString& contents)
 {
     const int max_excerpts(25);
-    const int max_unmerged_excerpts(max_excerpts + 10);
+    const int max_unmerged_excerpts(max_excerpts + 100);
     QMap<int, int> exc_endpos;
 
     for (int i = 0; i < _patterns.count(); ++i)
     {
         const searchPattern& pattern(_patterns.at(i));
         const searchPattern::modifiers& modifier(pattern.modifier());
+        pattern.initializeScores();
         if (modifier.NOT)
             continue;
-        if (modifier.scope != "all" && modifier.scope != "file")
+        if (modifier.scope != QLatin1String("all") && modifier.scope != QLatin1String("file"))
             continue;
         int n_excerpts(0);
         int pos(0);
@@ -394,10 +512,17 @@ const QString bibSearcher::excerpts(const QString& contents) const
             {
                 if (++n_excerpts > max_unmerged_excerpts)
                     break;
-                exc_endpos.insert(pos, qMax(pos + pattern.matchedLength(), exc_endpos.value(pos)));
+                if (_do_rank_results)
+                    pattern.updateScore();
+                exc_endpos.insert(pos, std::max(pos + pattern.matchedLength(), exc_endpos.value(pos)));
                 pos += pattern.matchedLength();
             }
         }
+        if (_do_rank_results)
+        {
+            _reference_score += pattern.matchedScore();
+            _reference_match_counter = pattern.matchedCounter();
+        }
     }
     if (exc_endpos.isEmpty())
         return QString();
@@ -428,20 +553,21 @@ const QString bibSearcher::excerpts(const QString& contents) const
 
     bool item_begins(true);
     bool item_complete;
-    const int items(qMin(i_pos.count(), max_excerpts));
+    const int items(std::min(i_pos.count(), max_excerpts));
 
     for (int i = 0; i < items; ++i)
     {
         const int pos(i_pos.at(i));
         const int length(exc_endpos.value(pos) - pos);
-        const QString match("<span>" + c2bUtils::toHtmlString(contents.mid(pos, length)) + "</span>");
+        const QString match(QLatin1String("<span>") + c2bUtils::toHtmlString(contents.mid(pos, length)) +
+                            QLatin1String("</span>"));
 
         if (item_begins)
         {
             QString pre_match(contents.mid(pos - context_length, context_length));
             pre_match.remove(lead_truncated_words);
             pre_match = c2bUtils::toHtmlString(pre_match);
-            exc += "&#8226; ..." + pre_match + match;
+            exc += QLatin1String("&#8226; ...") + pre_match + match;
         }
         else
             exc += match;
@@ -465,24 +591,25 @@ const QString bibSearcher::excerpts(const QString& contents) const
         }
     }
 
-    exc = "</p><p id=\"excerpt\">" + exc;
+    exc = QLatin1String("</p><p id=\"excerpt\">") + exc;
     if (i_pos.count() >= max_excerpts)
         exc += tr("</p><p><b>Found more than %1 occurrences</b>.").arg(max_excerpts);
     return exc;
 }
 
-const QString bibSearcher::highlight(const QString& abstract) const
+QString bibSearcher::highlight(const QString& abstract)
 {
     if (abstract.isEmpty())
         return abstract;
     QMap<int, int> endpos;
     for (int i = 0; i < _patterns.count(); ++i)
     {
-        const searchPattern& pattern = _patterns.at(i);
-        const searchPattern::modifiers& modifier = pattern.modifier();
+        const searchPattern& pattern(_patterns.at(i));
+        const searchPattern::modifiers& modifier(pattern.modifier());
+        pattern.initializeScores();
         if (modifier.NOT)
             continue;
-        if (modifier.scope != "all" && modifier.scope != "abstract")
+        if (modifier.scope != QLatin1String("all") && modifier.scope != QLatin1String("abstract"))
             continue;
         int pos(0);
         while (pos >= 0)
@@ -490,10 +617,17 @@ const QString bibSearcher::highlight(const QString& abstract) const
             pos = pattern.indexIn(abstract, pos);
             if (pos > -1)
             {
-                endpos.insert(pos, qMax(pos + pattern.matchedLength(), endpos.value(pos)));
+                if (_do_rank_results)
+                    pattern.updateScore();
+                endpos.insert(pos, std::max(pos + pattern.matchedLength(), endpos.value(pos)));
                 pos += pattern.matchedLength();
             }
         }
+        if (_do_rank_results)
+        {
+            _reference_score += pattern.matchedScore();
+            _reference_match_counter = pattern.matchedCounter();
+        }
     }
     if (endpos.isEmpty())
         return c2bUtils::toHtmlString(abstract);
@@ -521,15 +655,15 @@ const QString bibSearcher::highlight(const QString& abstract) const
     {
         const int pos(i_pos.at(i));
         const int length(endpos.value(pos) - pos);
-        hla += c2bUtils::toHtmlString(abstract.mid(npos, pos - npos)) + "<span>" +
-               c2bUtils::toHtmlString(abstract.mid(pos, length)) + "</span>";
+        hla += c2bUtils::toHtmlString(abstract.mid(npos, pos - npos)) + QLatin1String("<span>") +
+               c2bUtils::toHtmlString(abstract.mid(pos, length)) + QLatin1String("</span>");
         npos = endpos.value(pos);
     }
     hla += c2bUtils::toHtmlString(abstract.mid(npos, abstract.length() - npos));
     return hla;
 }
 
-const QString bibSearcher::location(const QString& fn, const bibReference& ref) const
+QString bibSearcher::location(const QString& fn, const bibReference& ref) const
 {
     const QString at("<a href=\"%1:%2\" class=\"anchor\">"
                      "<img src=\":/icons/icons/edit16.png\" alt=\"action\" width=\"16\" height=\"16\" /></a>");
