@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef CB2BIB_UTILITIES_H
@@ -12,14 +12,20 @@
 #include <QFileInfo>
 #include <QRegExp>
 #include <QString>
-#include <QStringMatcher>
+
 #include <QtDebug>
 
+#ifdef C2B_TRACE_MEMORY
+#include <iostream>
+#include <sys/resource.h>
+#endif
+
+class txtmatcher;
+
 
 /**
     cb2Bib core utilities
 */
-
 namespace c2bUtils
 {
 
@@ -31,6 +37,7 @@ enum AsciiConversion
     KeepWords,
     Transliterate
 };
+
 extern QString setCapitalization(const QString& str);
 extern QString toAscii(const QString& str, const AsciiConversion type);
 extern QString& bibToC2b(QString& str);
@@ -39,46 +46,16 @@ extern QString& fillString(QString& str, const QRegExp& pattern, const QChar& ch
 extern QString& fillString(QString& str, const QRegularExpression& pattern, const QChar& ch);
 extern QString& fillString(QString& str, const QString& pattern, const QChar& ch);
 extern QString& fillString(QString& str, const QStringMatcher& pattern, const QChar& ch);
+extern QString& fillString(QString& str, const txtmatcher& pattern, const QChar& ch);
+extern QString& fullBibToC2b(QString& str);
 extern QString& simplifyString(QString& str);
 extern QString& stripDiacritics(QString& str);
 
-static const QRegExp pnasGreekLetters("[\\{\\[\\(](alpha|beta|gamma|delta|varepsilon|"
-                                      "zeta|eta|theta|iota|kappa|lambda|mu|nu|xi|"
-                                      "omicron|pi|rho|sigmaf|varsigma|sigma|tau|"
-                                      "upsilon|phi|chi|psi|omega|vartheta|varphi|"
-                                      "varpi|digamma|varkappa|varrho|epsilon)[\\}\\]\\)]",
-                                      Qt::CaseInsensitive); // Only used in QString::replace which keeps QRegExp const
-static const QRegExp isBibToC2b("[\\{\\[\\$\\(\\\\<>]");
-static const QRegExp nonAsciiLetter("[^A-Za-z]");
-static const QRegExp nonLetter("\\W");
-static const QStringMatcher hasLatexDiacritic("{\\");
-static const QStringMatcher hasLatexSymbol("$\\");
-
-static const QString arxivUrl("https://arxiv.org/abs/%1");
-// Link set according to: "Creating a Web Link to the Entrez Databases",
-// http://www.ncbi.nlm.nih.gov/books/bv.fcgi?rid=helplinks.chapter.linkshelp#linkshelp.Retrieve_PubMed_Cita
-static const QString pubmedUrl("https://www.ncbi.nlm.nih.gov/pubmed/%1");
-static const QString metadatasection("\n[Raw Metadata\n%1\n/Raw Metadata]\n");
-
-inline QString& fullBibToC2b(QString& str)
-{
-    // Escape TeX and other special characters to Unicode
-    if (!str.contains(isBibToC2b))
-        return str;
-    // PNAS Style
-    str.replace(pnasGreekLetters, "$\\\\1$");
-    str.replace("{micro}", "$\\mu$");
-    str.replace("{middle dot}", "$\\cdot$");
-    // Sub and superscripts
-    str.replace(QRegExp("<sub>([^<]*)</sub>"), "$_{\\1}$");
-    str.replace(QRegExp("<sup>([^<]*)</sup>"), "$^{\\1}$");
-    str.replace(QRegExp("\\[sub ([^\\]]*)\\]"), "$_{\\1}$");
-    str.replace(QRegExp("\\[sup ([^\\]]*)\\]"), "$^{\\1}$");
-    str.replace(QRegExp("\\}\\$\\$([_\\^])\\{"), "}\\1{"); // merge if both
-    // TeX to Unicode
-    bibToC2b(str);
-    return str;
-}
+extern const QRegExp nonAsciiLetter;
+extern const QRegExp nonLetter;
+extern const QString arxivUrl;
+extern const QString metadatasection;
+extern const QString pubmedUrl;
 
 inline QString& cleanEquations(QString& str)
 {
@@ -99,7 +76,7 @@ inline QString& cleanEquations(QString& str)
         if (str.at(i) == eq)
         {
             bool has_eq(false);
-            for (int j = i + 1; j < qMin(i + 70, n); ++j) // Set a max equation length
+            for (int j = i + 1; j < std::min(i + 70, n); ++j) // Set a max equation length
                 if (str.at(j) == eq)
                 {
                     has_eq = true;
@@ -127,11 +104,11 @@ inline QString& cleanTitle(QString& title, const bool clean_period = false)
 {
     // Remove TeX braces and equation $
     cleanEquations(title);
-    title.remove('{');
-    title.remove('}');
+    title.remove(QLatin1Char('{'));
+    title.remove(QLatin1Char('}'));
     title = title.trimmed();
     if (clean_period && title.length() > 0)
-        if (title[title.length() - 1] == '.')
+        if (title[title.length() - 1] == QLatin1Char('.'))
             title.chop(1);
     return title;
 }
@@ -139,9 +116,9 @@ inline QString& cleanTitle(QString& title, const bool clean_period = false)
 inline QString toHtmlString(QString str)
 {
     // Encode some symbols to HTML for proper browser display
-    str.replace('<', "&#060;");
-    str.replace('>', "&#062;");
-    str.replace('%', "&#037;");
+    str.replace(QLatin1Char('<'), QLatin1String("&#060;"));
+    str.replace(QLatin1Char('>'), QLatin1String("&#062;"));
+    str.replace(QLatin1Char('%'), QLatin1String("&#037;"));
     str.replace(QRegExp("_\\{([^\\}]*)\\}"), "<sub>\\1</sub>");
     str.replace(QRegExp("\\^\\{([^\\}]*)\\}"), "<sup>\\1</sup>");
     cleanEquations(str);
@@ -194,14 +171,14 @@ inline QString documentAbsoluteName(const bool bibtexrelative, const QString& bi
         QDir ddir(QFileInfo(bibtexfn).absolutePath());
         // When bibtexrelative, should only be relative to bibtexfn, (safely) disregard if it is absolute.
         if (QDir(docdir).isRelative())
-            name = ddir.absolutePath() + '/' + docdir + '/' + QFileInfo(docfn).fileName();
+            name = ddir.absolutePath() + QLatin1Char('/') + docdir + QLatin1Char('/') + QFileInfo(docfn).fileName();
         else
-            name = ddir.absolutePath() + '/' + QFileInfo(docfn).fileName();
+            name = ddir.absolutePath() + QLatin1Char('/') + QFileInfo(docfn).fileName();
     }
     else
         // The docdir should be absolute here, whether or not working in USB mode. If it was relative,
         // this will set it with respect the application directory.
-        name = QDir(docdir).absolutePath() + '/' + QFileInfo(docfn).fileName();
+        name = QDir(docdir).absolutePath() + QLatin1Char('/') + QFileInfo(docfn).fileName();
     return QDir::toNativeSeparators(QDir::cleanPath(name));
 }
 
@@ -216,13 +193,13 @@ inline QString documentFilename(const bool bibtexrelative, const QString& bibtex
     {
         QDir ddir(QFileInfo(bibtexfn).absolutePath());
         if (QDir(docdir).isRelative())
-            name = ddir.absolutePath() + '/' + docdir + '/' + QFileInfo(docfn).fileName();
+            name = ddir.absolutePath() + QLatin1Char('/') + docdir + QLatin1Char('/') + QFileInfo(docfn).fileName();
         else
-            name = ddir.absolutePath() + '/' + QFileInfo(docfn).fileName();
+            name = ddir.absolutePath() + QLatin1Char('/') + QFileInfo(docfn).fileName();
         name = ddir.relativeFilePath(name);
     }
     else
-        name = QDir(docdir).absolutePath() + '/' + QFileInfo(docfn).fileName();
+        name = QDir(docdir).absolutePath() + QLatin1Char('/') + QFileInfo(docfn).fileName();
     return QDir::toNativeSeparators(QDir::cleanPath(name));
 }
 
@@ -236,9 +213,9 @@ inline QString documentDirName(const bool bibtexrelative, const QString& bibtexf
     {
         QDir ddir(QFileInfo(bibtexfn).absolutePath());
         if (QDir(docdir).isRelative())
-            name = ddir.absolutePath() + '/' + docdir;
+            name = ddir.absolutePath() + QLatin1Char('/') + docdir;
         else
-            name = docdir + '/';
+            name = docdir + QLatin1Char('/');
         name = ddir.relativeFilePath(name);
     }
     else
@@ -317,15 +294,16 @@ inline int nearInteger(double a)
 
 inline bool inBraces(const int pos, const QString& str, QString* in)
 {
-    if (str.at(pos - 1) == '{') // pos > 0 always
+    if (str.at(pos - 1) == QLatin1Char('{')) // pos > 0 always
     {
         int open_braces(1);
         const QChar open('{');
         const QChar close('}');
-        QChar si;
         for (int i = pos; i < str.length(); ++i)
         {
-            si = str.at(i);
+            if (str.at(i) < open)
+                continue;
+            const QChar& si(str.at(i));
             if (si == open)
                 open_braces++;
             else if (si == close)
@@ -361,11 +339,11 @@ inline QString fromQtXmlString(QString str)
 {
     // Workaround (It will be fixed in Qt 4.5)
     // Escape toXmlString already done by ExifTool
-    str.replace("%%#39;", "'");
-    str.replace("%%amp;", "&");
-    str.replace("%%gt;", ">");
-    str.replace("%%lt;", "<");
-    str.replace("%%quot;", "\"");
+    str.replace(QLatin1String("%%#39;"), QLatin1String("'"));
+    str.replace(QLatin1String("%%amp;"), QLatin1String("&"));
+    str.replace(QLatin1String("%%gt;"), QLatin1String(">"));
+    str.replace(QLatin1String("%%lt;"), QLatin1String("<"));
+    str.replace(QLatin1String("%%quot;"), QLatin1String("\""));
     return str;
 }
 
@@ -373,14 +351,21 @@ inline QString toQtXmlString(QString str)
 {
     // Workaround (It will be fixed in Qt 4.5)
     // Escape toXmlString already done by ExifTool
-    str.replace("&#39;", "%%#39;");
-    str.replace("&amp;", "%%amp;");
-    str.replace("&gt;", "%%gt;");
-    str.replace("&lt;", "%%lt;");
-    str.replace("&quot;", "%%quot;");
+    str.replace(QLatin1String("&#39;"), QLatin1String("%%#39;"));
+    str.replace(QLatin1String("&amp;"), QLatin1String("%%amp;"));
+    str.replace(QLatin1String("&gt;"), QLatin1String("%%gt;"));
+    str.replace(QLatin1String("&lt;"), QLatin1String("%%lt;"));
+    str.replace(QLatin1String("&quot;"), QLatin1String("%%quot;"));
     return str;
 }
-
+#ifdef C2B_TRACE_MEMORY
+inline void print_maximum_resident_set_size()
+{
+    rusage usage;
+    if (getrusage(RUSAGE_SELF, &usage) == 0)
+        std::cerr << "[cb2bib] maxrss: " << usage.ru_maxrss << std::endl;
+}
+#endif
 inline void warn(const QString& ms)
 {
     qWarning("[cb2bib] %s.", (const char*)ms.toLatin1());
@@ -397,36 +382,19 @@ inline void debug(const QString&
 #endif
 }
 
-extern const QString fromUtf8(const QByteArray& ba);
-
-#ifdef C2B_USE_LZO
-namespace lzo
+inline QByteArray stringToByteArray(const QString& s)
 {
-static const int HEADER_LENGTH = 10;
-extern const QByteArray compress(const QByteArray& data);
-extern const QByteArray uncompress(const QByteArray& data);
-} // namespace lzo
-
-inline const QByteArray compress(const QByteArray& data)
-{
-    return lzo::compress(data);
+    return QByteArray(reinterpret_cast<const char*>(s.unicode()), s.size() * sizeof(ushort));
 }
 
-inline const QByteArray uncompress(const QByteArray& data)
+inline QString byteArrayToString(const QByteArray& ba)
 {
-    return lzo::uncompress(data);
-}
-#else
-inline const QByteArray compress(const QByteArray& data)
-{
-    return qCompress(data);
+    return QString(reinterpret_cast<const QChar*>(ba.constData()), ba.size() / sizeof(ushort));
 }
 
-inline const QByteArray uncompress(const QByteArray& data)
-{
-    return qUncompress(data);
-}
-#endif
+extern QString fromUtf8(const QByteArray& ba);
+extern QByteArray compressString(const QString& decompressed);
+extern QString decompressString(const QByteArray& compressed);
 
 } // namespace c2bUtils
 
