@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "collectionAnalyzer.h"
@@ -13,6 +13,8 @@
 
 #include <cmath>
 
+namespace
+{
 
 template <typename T>
 class lengthsorting
@@ -34,10 +36,9 @@ private:
 };
 
 // Template double_sort was adapted from qSortHelper by Pere Constans.
-// qSortHelper is copyrighted by:
-// Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies),
+// qSortHelper is copyrighted by
+// (C) 2011 Nokia Corporation and/or its subsidiary(-ies),
 // and released under GLP/LGPL license.
-// http://www.qt.gitorious.org/qt/qt/blobs/4.7/src/corelib/tools/qalgorithms.h
 template <typename T1, typename T2>
 void double_sort(int start, int end, T1* v1, T2* v2)
 {
@@ -51,25 +52,25 @@ top:
     int pivot = start + span / 2;
     if ((*v1)[end] > (*v1)[start])
     {
-        qSwap((*v1)[end], (*v1)[start]);
-        qSwap((*v2)[end], (*v2)[start]);
+        std::swap((*v1)[end], (*v1)[start]);
+        std::swap((*v2)[end], (*v2)[start]);
     }
     if (span == 2)
         return;
     if ((*v1)[pivot] > (*v1)[start])
     {
-        qSwap((*v1)[pivot], (*v1)[start]);
-        qSwap((*v2)[pivot], (*v2)[start]);
+        std::swap((*v1)[pivot], (*v1)[start]);
+        std::swap((*v2)[pivot], (*v2)[start]);
     }
     if ((*v1)[end] > (*v1)[pivot])
     {
-        qSwap((*v1)[end], (*v1)[pivot]);
-        qSwap((*v2)[end], (*v2)[pivot]);
+        std::swap((*v1)[end], (*v1)[pivot]);
+        std::swap((*v2)[end], (*v2)[pivot]);
     }
     if (span == 3)
         return;
-    qSwap((*v1)[pivot], (*v1)[end]);
-    qSwap((*v2)[pivot], (*v2)[end]);
+    std::swap((*v1)[pivot], (*v1)[end]);
+    std::swap((*v2)[pivot], (*v2)[end]);
     while (low < high)
     {
         while (low < high && (*v1)[low] > (*v1)[end])
@@ -78,8 +79,8 @@ top:
             --high;
         if (low < high)
         {
-            qSwap((*v1)[low], (*v1)[high]);
-            qSwap((*v2)[low], (*v2)[high]);
+            std::swap((*v1)[low], (*v1)[high]);
+            std::swap((*v2)[low], (*v2)[high]);
             ++low;
             --high;
         }
@@ -88,14 +89,16 @@ top:
     }
     if ((*v1)[low] > (*v1)[end])
         ++low;
-    qSwap((*v1)[end], (*v1)[low]);
-    qSwap((*v2)[end], (*v2)[low]);
+    std::swap((*v1)[end], (*v1)[low]);
+    std::swap((*v2)[end], (*v2)[low]);
     double_sort(start, low, v1, v2);
     start = low + 1;
     ++end;
     goto top;
 }
 
+} // namespace
+
 
 collectionAnalyzer::collectionAnalyzer()
     : _ndocuments(0), _nsentences(0), _nsimilar(0), _settingsP(settings::instance()) {}
@@ -172,7 +175,7 @@ void collectionAnalyzer::setDocumentKeywords(const QString& documentfn)
         return;
 
     lengthsorting<QVarLengthArray<QString>> ls(_sentences);
-    qSort(dsentences.begin(), dsentences.end(), ls);
+    std::sort(dsentences.begin(), dsentences.end(), ls);
 
     for (int i = 0; i < ndsentences; ++i)
     {
@@ -187,7 +190,7 @@ void collectionAnalyzer::setDocumentKeywords(const QString& documentfn)
         if (!redundant)
             _document_keyword_ids.append(dsentences.at(i));
     }
-    qSort(_document_keyword_ids);
+    std::sort(_document_keyword_ids.begin(), _document_keyword_ids.end());
 }
 
 void collectionAnalyzer::setKeywordDocuments(const QString& keyword)
