@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "collectionIndex.h"
@@ -15,26 +15,26 @@
 
 #include <QDataStream>
 #include <QRegularExpression>
-#include <QVarLengthArray>
 
 #include <time.h>
 
+#define C2B_DEBUG_COLLECTIONINDEX 0
 
+namespace
+{
 // Tunable parameters
 static const int _document_length_threshold(100000);
 static const int _in_long_document_sentence_repetition(3);
 static const int _in_short_document_sentence_repetition(2);
 static const int _inter_document_sentence_repetition(3);
 
-#if QT_VERSION >= 0x050400
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)) && (QT_VERSION < QT_VERSION_CHECK(5, 12, 0))
 static const QRegularExpression::PatternOptions _qre_pattern_options(QRegularExpression::UseUnicodePropertiesOption |
         QRegularExpression::OptimizeOnFirstUsageOption);
 #else
 static const QRegularExpression::PatternOptions _qre_pattern_options(QRegularExpression::UseUnicodePropertiesOption);
 #endif
 
-#define C2B_DEBUG_COLLECTIONINDEX 0
-
 class reversedsorting
 {
 public:
@@ -45,7 +45,7 @@ public:
         const int lj(sj.length());
         const QChar* a = si.unicode() + li - 1;
         const QChar* b = sj.unicode() + lj - 1;
-        int cl(qMin(li, lj));
+        int cl(std::min(li, lj));
         while (cl-- > 0)
         {
             if (*a == *b)
@@ -74,6 +74,8 @@ public:
     const QChar us;
 };
 
+} // namespace
+
 
 collectionIndex::collectionIndex(bibParser* bp)
     : _out(*(new QTextStream(stdout))), _bpP(bp), _space_char(QChar(' ')), _nerrors(0), _settingsP(settings::instance()) {}
@@ -158,18 +160,13 @@ int collectionIndex::index(const QString& dir)
     for (int i = 0; i < documents.count(); ++i)
     {
         QStringList sentences(_document_sentences.values(i));
-        qSort(sentences);
+        std::sort(sentences.begin(), sentences.end());
         _out << i << "  " << documents.at(i) << ':' << endl;
         for (int j = 0; j < sentences.count(); ++j)
             _out << "        " << sentences.at(j) << endl;
     }
 #endif
 
-    _out << QObject::tr("Cleaning arrays...") << endl;
-    _keysentences.clear();
-    _document_sentences.clear();
-    _out << QObject::tr("done") << endl;
-
     const QString cache_dir(_settingsP->fileName("cb2Bib/CacheDirectory"));
     const QString documentslfn(QDir::toNativeSeparators(cache_dir + "/documents.lc2b"));
     QFile documentslf(QDir::cleanPath(documentslfn));
@@ -196,7 +193,7 @@ int collectionIndex::index(const QString& dir)
         for (int i = 0; i < documents.count(); ++i)
         {
             QList<int> sentenceids(_document_sentenceids.values(i));
-            qSort(sentenceids);
+            std::sort(sentenceids.begin(), sentenceids.end());
             stream << sentenceids.count();
             for (int j = 0; j < sentenceids.count(); ++j)
                 stream << sentenceids.at(j);
@@ -231,14 +228,11 @@ void collectionIndex::setKeySentences(const int documentid, const QString& text)
                   : _in_long_document_sentence_repetition);
     for (QHash<QStringRef, int>::const_iterator si = docsentences.constBegin(); si != docsentences.constEnd(); ++si)
     {
-        const QStringRef& s(si.key());
-        const int& n(si.value());
-        if (n < dsr)
+        if (si.value() < dsr)
             continue;
-        const QString ss(s.toString());
+        const QString ss(si.key().toString());
         if (!isValidKeySentence(ss))
             continue;
-
         if (_keysentences.contains(ss))
             _keysentences[ss].update(documentid);
         else
@@ -281,7 +275,7 @@ void collectionIndex::analyzeKeySentences()
         }
     }
     ussorting uss;
-    qSort(validlist.begin(), validlist.end(), uss);
+    std::sort(validlist.begin(), validlist.end(), uss);
 
     const QString cache_dir(_settingsP->fileName("cb2Bib/CacheDirectory"));
     const QString sentenceslfn(QDir::toNativeSeparators(QDir::cleanPath(cache_dir + "/sentences.lc2b")));
@@ -294,7 +288,7 @@ void collectionIndex::analyzeKeySentences()
         const QChar hs('-');
         const QChar us('_');
         const QString ss("\\1 ");
-        QRegularExpression aprx(author::prefixes + '_', _qre_pattern_options);
+        QRegularExpression aprx(_bpP->authorPrefixes() + '_', _qre_pattern_options);
         for (int i = 0; i < validlist.count(); ++i)
         {
             QString v(validlist.at(i));
@@ -319,7 +313,7 @@ void collectionIndex::analyzeKeySentences()
             const QString& s(validlist.at(i));
             const KeysentenceData& sdata(_keysentences.value(s));
             QList<int> dl(sdata.documents);
-            qSort(dl);
+            std::sort(dl.begin(), dl.end());
             stream << dl.count();
             for (int j = 0; j < dl.count(); ++j)
                 stream << dl.at(j);
@@ -331,22 +325,70 @@ void collectionIndex::analyzeKeySentences()
         ++_nerrors;
         _out << QObject::tr("Error: %1 can not be written").arg(sentencesifn) << endl;
     }
-    for (int i = 0; i < validlist.count(); ++i)
+#ifdef C2B_TRACE_MEMORY
+    qDebug() << "After writing sentencesifn:";
+    c2bUtils::print_maximum_resident_set_size();
+#endif
+    const QString documentsifn(QDir::toNativeSeparators(cache_dir + "/documents.ic2b.tmp"));
+    QFile documentsif(documentsifn);
+    int document_sentenceids_count(0);
+    if (documentsif.open(QIODevice::WriteOnly))
     {
-        const QString& s(validlist.at(i));
-        const KeysentenceData& sdata(_keysentences.value(s));
-        for (int j = 0; j < sdata.documents.count(); ++j)
-            _document_sentenceids.insert(sdata.documents.at(j), i);
+        QDataStream stream(&documentsif);
+        for (int i = 0; i < validlist.count(); ++i)
+        {
+            const QString& s(validlist.at(i));
+            const KeysentenceData& sdata(_keysentences.value(s));
+            document_sentenceids_count += sdata.documents.count();
+            for (int j = 0; j < sdata.documents.count(); ++j)
+                stream << sdata.documents.at(j) << i;
+        }
+        documentsif.close();
+    }
+    else
+    {
+        ++_nerrors;
+        _out << QObject::tr("Error: %1 can not be written").arg(documentsifn) << endl;
     }
 
-#if C2B_DEBUG_COLLECTIONINDEX
-    qSort(taggedvalidlist);
-    for (int i = 0; i < taggedvalidlist.count(); ++i)
-        _out << taggedvalidlist.at(i) << endl;
-#endif
     _out << QObject::tr("Raw keyword sentences: ") << _keysentences.size() << endl;
     _out << QObject::tr("Keyword sentences: ") << validlist.count() << endl;
     _out << QObject::tr("done") << endl;
+#if !C2B_DEBUG_COLLECTIONINDEX
+    _out << QObject::tr("Clearing arrays...") << endl;
+    _keysentences.clear();
+    _document_sentences.clear();
+    _out << QObject::tr("done") << endl;
+#endif
+#ifdef C2B_TRACE_MEMORY
+    qDebug() << "After clearing arrays:";
+    c2bUtils::print_maximum_resident_set_size();
+#endif
+    if (documentsif.open(QIODevice::ReadOnly))
+    {
+        QDataStream stream(&documentsif);
+        for (int l = 0, d, i; l < document_sentenceids_count; ++l)
+        {
+            stream >> d >> i;
+            _document_sentenceids.insert(d, i);
+        }
+        documentsif.close();
+        documentsif.remove();
+    }
+    else
+    {
+        ++_nerrors;
+        _out << QObject::tr("Error: %1 can not be read").arg(documentsifn) << endl;
+    }
+#ifdef C2B_TRACE_MEMORY
+    qDebug() << "After inserting _document_sentenceids:";
+    c2bUtils::print_maximum_resident_set_size();
+#endif
+#if C2B_DEBUG_COLLECTIONINDEX
+    std::sort(taggedvalidlist.begin(), taggedvalidlist.end());
+    for (int i = 0; i < taggedvalidlist.count(); ++i)
+        _out << taggedvalidlist.at(i) << endl;
+#endif
 }
 
 void collectionIndex::cleanupKeySentences()
@@ -357,14 +399,13 @@ void collectionIndex::cleanupKeySentences()
     for (QMap<QString, KeysentenceData>::const_iterator si = _keysentences.constBegin(); si != _keysentences.constEnd();
          ++si)
     {
-        const int& v(si.value().ndocuments);
-        if (v < _inter_document_sentence_repetition)
+        if (si.value().ndocuments < _inter_document_sentence_repetition)
             continue;
         keysentenceskeys.append(si.key());
     }
     const int nkeysentenceskeys(keysentenceskeys.count());
 
-    qSort(keysentenceskeys);
+    std::sort(keysentenceskeys.begin(), keysentenceskeys.end());
     for (int i = 0; i < nkeysentenceskeys - 1; ++i)
     {
         const QString& si(keysentenceskeys.at(i));
@@ -374,7 +415,7 @@ void collectionIndex::cleanupKeySentences()
     }
 
     reversedsorting rs;
-    qSort(keysentenceskeys.begin(), keysentenceskeys.end(), rs);
+    std::sort(keysentenceskeys.begin(), keysentenceskeys.end(), rs);
     for (int i = 0; i < nkeysentenceskeys - 1; ++i)
     {
         const QString& si(keysentenceskeys.at(i));
@@ -515,7 +556,7 @@ collectionIndex::KeysentenceData* collectionIndex::_digest_sentence(KeysentenceD
         const int nd(ksdndmax->documents.count());
         for (int i = 0; i < nd; ++i)
         {
-            const int& did(ksdndmax->documents.at(i));
+            const int did(ksdndmax->documents.at(i));
             if (!ksd->documents.contains(did))
                 ksd->documents.append(did);
         }
@@ -528,7 +569,7 @@ collectionIndex::KeysentenceData* collectionIndex::_digest_sentence(KeysentenceD
         const int nd(ksd->documents.count());
         for (int i = 0; i < nd; ++i)
         {
-            const int& did(ksd->documents.at(i));
+            const int did(ksd->documents.at(i));
             if (!ksdndmax->documents.contains(did))
                 ksdndmax->documents.append(did);
         }
@@ -1458,8 +1499,7 @@ bool collectionIndex::isValidKeySentence(const QString& text) const
 
 QString collectionIndex::preprocessedText(const QString& journal, const QString& text) const
 {
-    QString pt(text);
-    pt = pt.toLower();
+    QString pt(text.toLower());
     if (journal.contains(_space_char))
     {
         QStringList jns;
@@ -1474,8 +1514,8 @@ QString collectionIndex::preprocessedText(const QString& journal, const QString&
             c2bUtils::fillString(pt, QStringMatcher(jns.at(i), Qt::CaseSensitive), '.');
     }
 
-    replace(pt, '"', ' ');
-    replace(pt, '-', '_');
+    c2bUtils::fillString(pt, txtmatcher("\"", Qt::CaseSensitive, 0), ' ');
+    c2bUtils::fillString(pt, txtmatcher("-", Qt::CaseSensitive, 0), '_');
     pt.replace(QRegularExpression("_{2,}", _qre_pattern_options), "_");
 
     pt.replace(QRegularExpression("\\bin *situ\\b", _qre_pattern_options), " in_situ ");
@@ -1489,20 +1529,20 @@ QString collectionIndex::preprocessedText(const QString& journal, const QString&
     c2bUtils::fillString(pt, QRegularExpression("\\bbased (?=on\\b)", _qre_pattern_options), ' ');
     c2bUtils::fillString(pt, QRegularExpression("\\bin order (?=to\\b)", _qre_pattern_options), ' ');
 
-    c2bUtils::fillString(pt, QStringMatcher(" a ", Qt::CaseSensitive), ' ');
-    c2bUtils::fillString(pt, QStringMatcher(" an ", Qt::CaseSensitive), ' ');
-    c2bUtils::fillString(pt, QStringMatcher(" its ", Qt::CaseSensitive), ' ');
-    c2bUtils::fillString(pt, QStringMatcher(" the ", Qt::CaseSensitive), ' ');
-    c2bUtils::fillString(pt, QStringMatcher(" their ", Qt::CaseSensitive), ' ');
-    c2bUtils::fillString(pt, QStringMatcher(" '", Qt::CaseSensitive), ' ');
-    c2bUtils::fillString(pt, QStringMatcher("' ", Qt::CaseSensitive), ' ');
+    c2bUtils::fillString(pt, txtmatcher(" a ", Qt::CaseSensitive, 0), ' ');
+    c2bUtils::fillString(pt, txtmatcher(" an ", Qt::CaseSensitive, 2), ' ');
+    c2bUtils::fillString(pt, txtmatcher(" its ", Qt::CaseSensitive, 3), ' ');
+    c2bUtils::fillString(pt, txtmatcher(" the ", Qt::CaseSensitive, 2), ' ');
+    c2bUtils::fillString(pt, txtmatcher(" their ", Qt::CaseSensitive, 2), ' ');
+    c2bUtils::fillString(pt, txtmatcher(" '", Qt::CaseSensitive, 1), ' ');
+    c2bUtils::fillString(pt, txtmatcher("' ", Qt::CaseSensitive, 0), ' ');
 
     // Set additional breakpoints
-    c2bUtils::fillString(pt, QStringMatcher(" are ", Qt::CaseSensitive), '.');
-    c2bUtils::fillString(pt, QStringMatcher(" be ", Qt::CaseSensitive), '.');
-    c2bUtils::fillString(pt, QStringMatcher(" is ", Qt::CaseSensitive), '.');
-    c2bUtils::fillString(pt, QStringMatcher(" was ", Qt::CaseSensitive), '.');
-    c2bUtils::fillString(pt, QStringMatcher(" were ", Qt::CaseSensitive), '.');
+    c2bUtils::fillString(pt, txtmatcher(" are ", Qt::CaseSensitive, 2), '.');
+    c2bUtils::fillString(pt, txtmatcher(" be ", Qt::CaseSensitive, 1), '.');
+    c2bUtils::fillString(pt, txtmatcher(" is ", Qt::CaseSensitive, 2), '.');
+    c2bUtils::fillString(pt, txtmatcher(" was ", Qt::CaseSensitive, 1), '.');
+    c2bUtils::fillString(pt, txtmatcher(" were ", Qt::CaseSensitive, 1), '.');
 
     c2bUtils::fillString(pt, QRegularExpression("\\binstitut\\w*", _qre_pattern_options), '.');
     c2bUtils::fillString(pt, QRegularExpression("\\buniversi\\w*", _qre_pattern_options), '.');
@@ -1511,7 +1551,7 @@ QString collectionIndex::preprocessedText(const QString& journal, const QString&
 
     // Normalize proper names
     c2bUtils::fillString(pt, QRegularExpression("\\bdo not\\b", _qre_pattern_options), '.');
-    pt.replace(QRegularExpression("\\b" + author::prefixes + "\\s", _qre_pattern_options),
+    pt.replace(QRegularExpression("\\b" + _bpP->authorPrefixes() + "\\s", _qre_pattern_options),
                QString("\\1%1").arg(QChar(127)));
     replace(pt, QChar(127), '_');
 
