@@ -1,13 +1,15 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "compositePattern.h"
 
 #include "cb2bib_utilities.h"
 
+namespace
+{
 
 template <typename T>
 class descending
@@ -23,16 +25,14 @@ private:
     const T& _data;
 };
 
+} // namespace
+
 
 compositePattern::compositePattern()
     : _case_sensitivity(Qt::CaseSensitive), _is_multipattern(false), _subpattern_count(0), _matched_length(-1) {}
 
 compositePattern::compositePattern(const QString& pattern, const Qt::CaseSensitivity cs)
-    : _string(pattern.simplified()),
-      _case_sensitivity(cs),
-      _is_multipattern(false),
-      _subpattern_count(0),
-      _matched_length(-1) {}
+    : _string(pattern), _case_sensitivity(cs), _is_multipattern(false), _subpattern_count(0), _matched_length(-1) {}
 
 
 QString compositePattern::escape(const QString& str, const Qt::CaseSensitivity cs)
@@ -55,5 +55,5 @@ void compositePattern::set_sort_index()
     for (int i = 0; i < _subpattern_count; ++i)
         _index[i] = i;
     descending<QList<double>> sort(_ranks);
-    qSort(_index.begin(), _index.end(), sort);
+    std::sort(_index.begin(), _index.end(), sort);
 }
