@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef COREBIBPARSER_H
@@ -9,8 +9,8 @@
 
 #include "authorString.h"
 #include "bibReference.h"
-#include "cb2bib_utilities.h"
 #include "settings.h"
+#include "txtmatcher.h"
 
 #include <QDir>
 #include <QObject>
@@ -32,7 +32,8 @@ public:
 
     QString referenceToBibTeX(const bibReference& ref) const;
     QString referenceToFomattedBibTeX(const bibReference& ref) const;
-    bibReference wholeReference(const QString& str);
+    QString singleReferenceField(const QString& field, const bibReference& ref) const;
+    bibReference wholeReference(const QString& str) const;
     bool referenceAtKey(const QString& key, const QString& str, bibReference* ref);
     bool referencesIn(const QString& str, bibReference* ref);
     void initReferenceParsing(const QString& dir, const QStringList& fields, bibReference* ref);
@@ -64,7 +65,7 @@ public:
     }
     inline int fieldCount(const bibReference& ref) const
     {
-        // Counting Non Empty Fields
+        // Counting non empty fields
         int n(0);
         bibReferenceIterator i;
         for (i = ref.constBegin(); i != ref.constEnd(); ++i)
@@ -75,10 +76,18 @@ public:
     inline QString& authorFromBibTeX(QString& as)
     {
         // Avoid BibTeX reverse names
-        if (as.contains(','))
+        if (as.contains(_comma))
             as = _authorString.toBibTeX(as, _settingsP->value("cb2Bib/UseFullNames").toBool());
         return as;
     }
+    inline QString authorFromMedline(const QString& author) const
+    {
+        return _authorString.fromMedline(author);
+    }
+    inline const QString& authorPrefixes() const
+    {
+        return _authorString.prefixes();
+    }
 
 
 protected:
@@ -86,42 +95,68 @@ protected:
     QString adjacentNumbers(const QString& numbers) const;
     QStringList _bibliographic_fields;
     QStringList _bibliographic_types;
+    QStringList _current_bibliographic_fields;
     QStringList _sorted_bibliographic_fields;
     authorString _authorString;
     settings* _settingsP;
 
 
 private:
-    QList<QRegExp> _bib_fields_nb_re;
-    QList<QRegExp> _bib_fields_re;
     QRegExp _bib_begin0_re;
     QRegExp _bib_begin1_re;
     QRegExp _bib_begin_re;
-    QRegExp _bib_key_re;
-    QRegExp _bib_type_re;
     QString _bib_file_dir;
+    const QChar _at;
     const QChar _close;
+    const QChar _colon;
     const QChar _comma;
+    const QChar _cr;
+    const QChar _hyphen;
+    const QChar _lca;
+    const QChar _lcz;
+    const QChar _nl;
     const QChar _open;
+    const QChar _period;
+    const QChar _pound;
+    const QChar _quote;
     const QChar _space;
+    const QChar _tilde;
+    const QChar _uca;
+    const QChar _ucz;
+    txtmatcher _bib_begin_at;
+    txtmatcher _bib_field_delimiter;
+
+    void referenceContents(const QString& str, bibReference* ref, int pos) const;
     void setFields();
     void setRegularExpressions();
     void setTypes();
 
+    void _parse_reference_fields(const QString& bibstr, const QStringList& fields, bibReference* ref) const;
+    int _in_braces_ends(const QChar* const b, const int p, const int length) const;
+
     inline int referenceStarts(const QString& str, int pos = 0) const
     {
-        int i;
-        if (pos == 0)
+        while (true)
         {
-            i = _bib_begin0_re.indexIn(str);
-            if (i < 0)
-                i = _bib_begin1_re.indexIn(str, pos);
+            const int i(_bib_begin_at.indexIn(str, pos));
+            if (i > 0)
+            {
+                for (int j = i - 1; j >= pos; --j)
+                    if (str.at(j) == _nl || str.at(j) == _cr)
+                        goto check;
+                    else if (!str.at(j).isSpace())
+                        goto next;
+                if (pos > 0)
+                    goto next;
+            }
+            else if (i < 0)
+                return i;
+check:
+            if (_bib_begin_re.indexIn(str, i, QRegExp::CaretAtOffset) == i)
+                return i;
+next:
+            pos = i + 2;
         }
-        else
-            i = _bib_begin1_re.indexIn(str, pos);
-        if (i < 0)
-            return i;
-        return _bib_begin_re.indexIn(str, i);
     }
     inline int referenceStarts(const QString& key, const QString& str) const
     {
@@ -134,7 +169,7 @@ private:
             return i;
         return str.indexOf(QRegExp("@\\w+\\s*\\{" + key + ','), i);
     }
-    inline int referenceEnds(const QString& str, int pos = 0) const
+    inline int referenceEnds(const QString& str, const int pos = 0) const
     {
         // If referenceStarts call is successful, we know for sure
         // that there is an opening { right after pos.
@@ -150,7 +185,9 @@ private:
         int open_braces(1);
         for (int i = brace_pos + 1; i < ref_length; ++i)
         {
-            const QChar& si = str.at(i);
+            if (str.at(i) < _open)
+                continue;
+            const QChar& si(str.at(i));
             if (si == _open)
                 open_braces++;
             else if (si == _close)
@@ -160,9 +197,10 @@ private:
         }
         return ref_length - 1;
     }
-    inline void setReferenceEnd(QString* str, const int& length) const
+    inline void setReferenceEnd(QString* str) const
     {
         // Set safer termination: field="..." } -> field="...",}
+        const unsigned int length(str->length());
         if (str->at(length - 2) == _space)
             (*str)[length - 2] = _comma;
         else
@@ -171,47 +209,11 @@ private:
     inline QString referenceAt(const QString& str, int* pos) const
     {
         // String str contains one or multiple references (file contents)
-        const int pos_(referenceEnds(str, *pos) + 1);
-        const QString str_ref(str.mid(*pos, pos_ - (*pos)));
-        *pos = pos_;
+        const int p(referenceEnds(str, *pos) + 1);
+        const QString str_ref(str.mid(*pos, p - (*pos)));
+        *pos = p;
         return str_ref;
     }
-    inline void referenceContents(const QString& str, bibReference* ref, int pos)
-    {
-        // File parsing for given fields in ref
-        ref->positionValue = pos;
-        QString str_ref(referenceAt(str, &pos));
-        ref->pos = pos;
-        ref->rawReference = str_ref;
-        c2bUtils::bibToC2b(str_ref);
-        c2bUtils::simplifyString(str_ref);
-        ref->unicodeReference = str_ref;
-        _bib_key_re.indexIn(str_ref);
-        ref->citeidName = _bib_key_re.cap(1);
-        _bib_type_re.indexIn(str_ref);
-        ref->typeName = _bib_type_re.cap(1).toLower();
-        setReferenceEnd(&str_ref, str_ref.length());
-        QString fvalue;
-        for (int i = 0; i < ref->_bib_fields_re.count(); ++i)
-        {
-            QRegExp* bf = &ref->_bib_fields_re[i];
-            pos = bf->indexIn(str_ref);
-            if (pos > 0)
-            {
-                if (c2bUtils::inBraces(pos + bf->matchedLength(), str_ref, &fvalue))
-                    (*ref)[ref->bib_fieldList.at(i)] = fvalue.trimmed();
-            }
-            else
-            {
-                bf = &ref->_bib_fields_nb_re[i];
-                if (bf->indexIn(str_ref) > -1)
-                    (*ref)[ref->bib_fieldList.at(i)] = bf->cap(1).trimmed();
-            }
-        }
-        if (ref->contains("file"))
-            if (!QDir::isAbsolutePath(ref->value("file")))
-                (*ref)["file"] = _bib_file_dir + ref->value("file");
-    }
 };
 
 #endif
