@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "document.h"
@@ -76,6 +76,10 @@ QString document::toString()
 
     normalize(doc, _conversion_mode);
 
+    // Recheck in case normalize reveals badly encoded PDFs
+    if (doc.isEmpty())
+        c2bUtils::warn(QObject::tr("Warning: Text conversion for file '%1' is empty").arg(_document_fn));
+
     return doc;
 }
 
@@ -315,7 +319,7 @@ QString& document::normalize(QString& doc, const Conversion mode)
 
     if (hreg)
     {
-        // Correct frequent misencoding of "fi" as circle R in PDFs
+        // Correct frequent misencoding of "fi" as circle R in PDFs (Adobe Standard Encoding)
         doc.replace(QRegExp(QString("%1([a-z])").arg(QChar(174))), "fi\\1");
     }
     if (hligatures)
