@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "documentCache.h"
@@ -44,17 +44,29 @@ void documentCache::load(const QString& fn, const documentContents::Type type)
             ds >> _cache;
         }
     }
-#ifdef C2B_USE_LZO
-    if (!_cache.contains("lzo"))
+#if defined(C2B_USE_LZSSE)
+    if (!_cache.contains("clzsse"))
     {
         _cache.clear();
-        _cache.insert("lzo", QByteArray());
+        _cache.insert("clzsse", QByteArray());
+    }
+#elif defined(C2B_USE_LZ4)
+    if (!_cache.contains("clz4"))
+    {
+        _cache.clear();
+        _cache.insert("clz4", QByteArray());
+    }
+#elif defined(C2B_USE_LZO)
+    if (!_cache.contains("clzo"))
+    {
+        _cache.clear();
+        _cache.insert("clzo", QByteArray());
     }
 #else
-    if (!_cache.contains("zlib"))
+    if (!_cache.contains("czlib"))
     {
         _cache.clear();
-        _cache.insert("zlib", QByteArray());
+        _cache.insert("czlib", QByteArray());
     }
 #endif
     _cache_load_size = _cache.size();
@@ -72,7 +84,7 @@ void documentCache::unload()
 
 bool documentCache::setCurrent(const QString& fn, int* pdfCounter, QString* logString, int* errorCounter)
 {
-    const QString doc_fn(fn.trimmed());
+    const QString doc_fn(QDir::cleanPath(fn.trimmed()));
     if (doc_fn.isEmpty())
     {
         _current.clear();
@@ -92,7 +104,7 @@ bool documentCache::setCurrent(const QString& fn, int* pdfCounter, QString* logS
             (*logString) += QObject::tr("% [cb2bib] %1\n").arg(doc.errorString());
             return false;
         }
-        _cache.insert(doc_fn, c2bUtils::compress(_current._text.toUtf8()));
+        _cache.insert(doc_fn, c2bUtils::compressString(_current._text));
         if (_content_type == documentContents::Simplified)
         {
             _current._text = c2bUtils::toAscii(_current._text, c2bUtils::KeepWords);
@@ -100,7 +112,7 @@ bool documentCache::setCurrent(const QString& fn, int* pdfCounter, QString* logS
         }
         else
             _current._signature = triads::textSignature(_current._text);
-        _cache.insert(skey, _current._signature.toUtf8());
+        _cache.insert(skey, c2bUtils::stringToByteArray(_current._signature));
         _current._is_text_loaded = true;
         _current._is_signature_loaded = true;
     }
@@ -110,7 +122,7 @@ bool documentCache::setCurrent(const QString& fn, int* pdfCounter, QString* logS
 
 bool documentCache::setCurrent(const QString& fn)
 {
-    const QString doc_fn(fn.trimmed());
+    const QString doc_fn(QDir::cleanPath(fn.trimmed()));
     if (doc_fn.isEmpty())
     {
         _current.clear();
@@ -126,7 +138,7 @@ bool documentCache::setCurrent(const QString& fn)
         _current._text = doc.toString();
         if (!doc.errorString().isEmpty())
             return false;
-        _cache.insert(doc_fn, c2bUtils::compress(_current._text.toUtf8()));
+        _cache.insert(doc_fn, c2bUtils::compressString(_current._text));
         if (_content_type == documentContents::Simplified)
         {
             _current._text = c2bUtils::toAscii(_current._text, c2bUtils::KeepWords);
@@ -134,7 +146,7 @@ bool documentCache::setCurrent(const QString& fn)
         }
         else
             _current._signature = triads::textSignature(_current._text);
-        _cache.insert(skey, _current._signature.toUtf8());
+        _cache.insert(skey, c2bUtils::stringToByteArray(_current._signature));
         _current._is_text_loaded = true;
         _current._is_signature_loaded = true;
     }
