@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef DOCUMENTCONTENTS_H
@@ -27,7 +27,7 @@ public:
     {
         if (!_is_signature_loaded)
         {
-            _signature = QString::fromUtf8(_cache.value(_signature_key));
+            _signature = c2bUtils::byteArrayToString(_cache.value(_signature_key));
             _is_signature_loaded = true;
         }
         return _signature;
@@ -38,10 +38,9 @@ public:
         if (!_is_text_loaded)
         {
             if (_type == Simplified)
-                _text = c2bUtils::toAscii(c2bUtils::fromUtf8(c2bUtils::uncompress(_cache.value(_text_key))),
-                                          c2bUtils::KeepWords);
+                _text = c2bUtils::toAscii(c2bUtils::decompressString(_cache.value(_text_key)), c2bUtils::KeepWords);
             else
-                _text = c2bUtils::fromUtf8(c2bUtils::uncompress(_cache.value(_text_key)));
+                _text = c2bUtils::decompressString(_cache.value(_text_key));
             _is_text_loaded = true;
         }
         return _text;
