@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "heuristicBibParser.h"
@@ -34,7 +34,7 @@ heuristicBibParser::heuristicBibParser(bibParser* bp)
       _journal_db(*bp->_journal_dbP)
 {
     _leading_non_letters = QRegExp("^[^<\\w]+");
-    // Char 65533 appears many times in pdftotext outputs on windows (seems an encoding error, though)
+    // Char 65533 appears many times in pdftotext outputs due to encoding errors
     _hyphens = QRegExp("\\s*[-" + QString(QChar(8211)) + QString(QChar(8722)) + QString(QChar(65533)) + "]+\\s*");
     _hyphen_nums = "(?:\\d+|\\d+-\\d+)";
     _hyphen_pages = "(?:\\d+|\\d+-\\d+p{0,2}|\\d+ \\d+pp)";
@@ -308,7 +308,7 @@ void heuristicBibParser::guessAuthor(const QString& tagged_text)
     simplified_text.replace(' ' + QChar(198) + ' ', " , "); // Fancy author separator
     simplified_text.replace(QChar(8226), ',');              // Fancy author separator
     simplified_text.replace(QChar(178), ' ');               // Superscript dagger as sometimes translated by pdftotext
-    author::simplifyString(simplified_text);
+    _aencoder.aunifier.simplifyString(simplified_text);
 
     // Capitalize and encode
     for (int i = 0; i < _word_prefix_lexicon.count(); ++i)
@@ -739,7 +739,7 @@ void heuristicBibParser::guessJournal(const QString& text)
             if (p == -1)
                 continue;
             const int jlength(_journal_db.fullsimplifiedFull(i).length());
-            const int d(1 + qMin(p - pheader, pfooter - p - jlength));
+            const int d(1 + std::min(p - pheader, pfooter - p - jlength));
             const double score(pow(double(jlength), 1.75) / double(d));
             if (score > oscore)
             {
@@ -753,7 +753,7 @@ void heuristicBibParser::guessJournal(const QString& text)
         if (p == -1)
             continue;
         const int jlength(_journal_db.fullsimplified(i).length());
-        const int d(1 + qMin(p - pheader, pfooter - p - jlength));
+        const int d(1 + std::min(p - pheader, pfooter - p - jlength));
         const double score(pow(double(jlength), 1.75) / double(d));
         if (score > oscore)
         {
