@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *
  *   Improvements and modifications:
@@ -9,7 +9,6 @@
  ***************************************************************************/
 #include "idMaker.h"
 
-#include "cb2bib_utilities.h"
 #include "settings.h"
 
 
@@ -20,7 +19,11 @@ idMaker::idMaker(const QString& patternKey, QObject* parento) : QObject(parento)
 }
 
 
-/** \page idplaceholders Predefined Cite and Document ID Placeholders
+/** \page predefinedplaceholders Predefined Placeholders
+
+
+  \section idplaceholders Cite and Document ID Placeholders
+
 
     - <tt><<author_all_abbreviated>></tt> Takes first three letters of the last
     word of all authors's last name in cite, and converts to lowercase.
@@ -28,7 +31,10 @@ idMaker::idMaker(const QString& patternKey, QObject* parento) : QObject(parento)
     - <tt><<author_all_initials>></tt> Takes capitalized initials of all
     authors in cite.
 
-    - <tt><<author_first>></tt> Takes first author last name/s.
+    - <tt><<author_first>></tt> Takes first author last name.
+
+    - <tt><<author_first_lowercase>></tt> Takes first author last name in
+    lowercase.
 
     - <tt><<citeid>></tt> This placeholder is meant to be used <b>alone, and
     only for document IDs</b>. It takes the pattern defined for the cite ID. If
@@ -49,6 +55,8 @@ idMaker::idMaker(const QString& patternKey, QObject* parento) : QObject(parento)
     truncate title to <tt>l</tt> characters use
     <tt><<title_underscored_l>></tt>.
 
+    - <tt><<title_first_word>></tt> First word in title, in lowercase.
+
     - <tt><<volume>></tt> Volume number.
 
     - <tt><<year_abbreviated>></tt> Last two digits from year.
@@ -71,49 +79,80 @@ idMaker::idMaker(const QString& patternKey, QObject* parento) : QObject(parento)
     BibTeX keys and platform independent filenames. Currently only ASCII
     characters are considered.
 
+
+  \section citeplaceholders Cite Command Placeholders
+
+    - <tt><<citeid>></tt> The <tt>citeid</tt> placeholder replicates the
+    pattern for each citation in the selected citation list. For example, the
+    pattern <tt>\\citenum{<<citeid>>}</tt> expands to <tt>\\citenum{cid1}
+    \\citenum{cid2} ... </tt>
+
+    - <tt><<prefix|citeids|separator>></tt> The <tt>citeids</tt> placeholder
+    replaces the selected citation list by prepending <tt>prefix</tt> and
+    appending <tt>separator</tt> within the pattern. For example, the markdown
+    pattern <tt>[<<\@|citeids|;>>]</tt> expands to <tt>[\@cid1; \@cid2;
+    ...]</tt>, and the LaTeX pattern <tt>\\citeauthor{<<|citeids|,>>}</tt>
+    expands to <tt>\\citeauthor{cid1, cid2, ...}</tt>.
+
+
+    <b>Note:</b> For additional information on cite commands see
+    \htmlonly
+    <a href="https://en.wikibooks.org/wiki/LaTeX/Bibliography_Management" target="_blank">LaTeX Bibliography
+  Management</a>
+    \endhtmlonly
+    and
+    \htmlonly
+    <a href="https://pandoc.org/MANUAL.html#citations" target="_blank">Pandoc User's Guide</a>.
+    \endhtmlonly
+
 */
 QString idMaker::makeID(const bibReference& reference)
 {
     if (_id_pattern.isEmpty())
         return QString();
-    if (_id_pattern.contains("<<citeid>>"))
+    if (_id_pattern.contains(QLatin1String("<<citeid>>")))
         return reference.citeidName;
 
     // Initialize fields
     _author = reference.anyAuthor();
-    _journal = reference.value("journal");
-    _pages = reference.value("pages");
+    _journal = reference.value(QLatin1String("journal"));
+    _pages = reference.value(QLatin1String("pages"));
     _title = reference.anyTitle();
-    _volume = reference.value("volume");
-    _year = reference.value("year");
+    _volume = reference.value(QLatin1String("volume"));
+    _year = reference.value(QLatin1String("year"));
 
     // Set cite ID
     QString id(_id_pattern);
-    if (_id_pattern.contains("<<author_first>>"))
+    if (_id_pattern.contains(QLatin1String("<<author_first>>")))
         make_author_first(&id);
-    else if (_id_pattern.contains("<<author_all_abbreviated>>"))
+    else if (_id_pattern.contains(QLatin1String("<<author_first_lowercase>>")))
+        make_author_first_lowercase(&id);
+    else if (_id_pattern.contains(QLatin1String("<<author_all_abbreviated>>")))
         make_author_all_abbreviated(&id);
-    else if (_id_pattern.contains("<<author_all_initials>>"))
+    else if (_id_pattern.contains(QLatin1String("<<author_all_initials>>")))
         make_author_all_initials(&id);
 
-    if (_id_pattern.contains("<<journal_initials>>"))
+    if (_id_pattern.contains(QLatin1String("<<journal_initials>>")))
         make_journal_initials(&id);
 
-    if (_id_pattern.contains("<<pages_first>>"))
+    if (_id_pattern.contains(QLatin1String("<<pages_first>>")))
         make_pages_first(&id);
-    else if (_id_pattern.contains("<<ppages_first>>"))
+    else if (_id_pattern.contains(QLatin1String("<<ppages_first>>")))
         make_ppages_first(&id);
 
     if (!_title_pattern.isEmpty())
         if (_id_pattern.contains(_title_pattern))
             make_title(&id);
 
-    if (_id_pattern.contains("<<volume>>"))
+    if (_id_pattern.contains(QLatin1String("<<title_first_word>>")))
+        make_title_first_word(&id);
+
+    if (_id_pattern.contains(QLatin1String("<<volume>>")))
         make_volume(&id);
 
-    if (_id_pattern.contains("<<year_abbreviated>>"))
+    if (_id_pattern.contains(QLatin1String("<<year_abbreviated>>")))
         make_year_abbreviated(&id);
-    else if (_id_pattern.contains("<<year_full>>"))
+    else if (_id_pattern.contains(QLatin1String("<<year_full>>")))
         make_year_full(&id);
 
     return id;
@@ -127,7 +166,18 @@ void idMaker::make_author_first(QString* id)
     _author = rx.cap(1);
     if (_author.contains(c2bUtils::nonAsciiLetter))
         _author = c2bUtils::toAscii(_author, c2bUtils::Cleanup);
-    id->replace("<<author_first>>", _author);
+    id->replace(QLatin1String("<<author_first>>"), _author);
+}
+
+void idMaker::make_author_first_lowercase(QString* id)
+{
+    QRegExp rx("([-'\\s\\w]+)(?:\\sand|$)");
+    rx.setMinimal(true);
+    rx.indexIn(_author);
+    _author = rx.cap(1).toLower();
+    if (_author.contains(c2bUtils::nonAsciiLetter))
+        _author = c2bUtils::toAscii(_author, c2bUtils::Cleanup);
+    id->replace(QLatin1String("<<author_first_lowercase>>"), _author);
 }
 
 void idMaker::make_author_all_abbreviated(QString* id)
@@ -147,7 +197,7 @@ void idMaker::make_author_all_abbreviated(QString* id)
     _author = temp_author.toLower();
     if (_author.contains(c2bUtils::nonAsciiLetter))
         _author = c2bUtils::toAscii(_author, c2bUtils::Cleanup);
-    id->replace("<<author_all_abbreviated>>", _author);
+    id->replace(QLatin1String("<<author_all_abbreviated>>"), _author);
 }
 
 void idMaker::make_author_all_initials(QString* id)
@@ -157,19 +207,19 @@ void idMaker::make_author_all_initials(QString* id)
     if (_author.contains(c2bUtils::nonAsciiLetter))
         _author = c2bUtils::toAscii(_author, c2bUtils::Cleanup);
     _author.remove(QRegExp("[a-z]"));
-    id->replace("<<author_all_initials>>", _author);
+    id->replace(QLatin1String("<<author_all_initials>>"), _author);
 }
 
 void idMaker::make_journal_initials(QString* id)
 {
     _journal.remove(QRegExp("[^A-Z]"));
-    id->replace("<<journal_initials>>", _journal);
+    id->replace(QLatin1String("<<journal_initials>>"), _journal);
 }
 
 void idMaker::make_pages_first(QString* id)
 {
     _pages = c2bUtils::firstPage(_pages);
-    id->replace("<<pages_first>>", _pages);
+    id->replace(QLatin1String("<<pages_first>>"), _pages);
 }
 
 void idMaker::make_ppages_first(QString* id)
@@ -178,7 +228,7 @@ void idMaker::make_ppages_first(QString* id)
     if (!_pages.isEmpty())
         if (_pages.at(0).isDigit())
             _pages = 'p' + _pages;
-    id->replace("<<ppages_first>>", _pages);
+    id->replace(QLatin1String("<<ppages_first>>"), _pages);
 }
 
 void idMaker::make_title(QString* id)
@@ -187,25 +237,40 @@ void idMaker::make_title(QString* id)
         _title = c2bUtils::toAscii(_title, c2bUtils::FromBibTeX);
     _title = _title.left(_title_max_length).trimmed(); // Avoid possible trailing blank
     if (_is_title_underscored)
-        _title.replace(' ', '_');
+        _title.replace(QLatin1Char(' '), QLatin1Char('_'));
     id->replace(_title_pattern, _title);
 }
 
+void idMaker::make_title_first_word(QString* id)
+{
+    if (_title.contains(c2bUtils::nonAsciiLetter))
+        _title = c2bUtils::toAscii(_title, c2bUtils::FromBibTeX);
+    const QStringList ws(_title.toLower().split(c2bUtils::nonAsciiLetter, QString::SkipEmptyParts));
+    _title.resize(0);
+    for (int w = 0; w < ws.count(); ++w)
+        if (ws.at(w).length() > 2 && ws.at(w) != QLatin1String("are") && ws.at(w) != QLatin1String("the"))
+        {
+            _title = ws.at(w);
+            break;
+        }
+    id->replace(QLatin1String("<<title_first_word>>"), _title);
+}
+
 void idMaker::make_volume(QString* id)
 {
     _volume.remove(' ');
-    id->replace("<<volume>>", _volume);
+    id->replace(QLatin1String("<<volume>>"), _volume);
 }
 
 void idMaker::make_year_abbreviated(QString* id)
 {
     _year = _year.right(2);
-    id->replace("<<year_abbreviated>>", _year);
+    id->replace(QLatin1String("<<year_abbreviated>>"), _year);
 }
 
 void idMaker::make_year_full(QString* id)
 {
-    id->replace("<<year_full>>", _year);
+    id->replace(QLatin1String("<<year_full>>"), _year);
 }
 
 void idMaker::loadSettings()
