@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "metadataParser.h"
@@ -21,11 +21,10 @@ GET_TABLE_OF_CONTENTS
 
   \section metadata_read Reading Metadata
 
-  Metadata in scientific documents is, unfortunately, rarely appreciated and
-  not widely used. When it comes to bibliographic metadata, the situation is
-  even quite deceiving: there is no accepted format specification, and the
-  reliability of publishers' metadata, if any at all, is questionable in many
-  cases.
+  Metadata in scientific documents had been rarely appreciated and used for
+  decades. For bibliographic metadata, no format specification had been widely
+  accepted. cb2Bib adapted back in 2008 the PDF predefined metadata
+  capabilities to set BibTeX bibliographic keys in document files.
 
   cb2Bib reads all XMP (a specific XML standard devised for metadata storage)
   packets found in the document. It then parses the XML strings looking for
@@ -70,23 +69,16 @@ GET_TABLE_OF_CONTENTS
 <bibtex:year>2007</bibtex:year>
 \endverbatim
 
-  which is similar to
-  \htmlonly
-  <a href="http://www.jabref.org/" target="_blank">JabRef</a>
-  \endhtmlonly
-  but differs on that cb2Bib strictly sticks to BibTeX and avoids (perhaps
-  unnecessary) syntax specialization in author strings.
-
   The BibTeX fields <tt>file</tt> and <tt>id</tt> are skip from writing. The
   former for the reason mentioned above, and the latter because it is easily
   generated by specialized BibTeX software according to each user preferences.
-  LaTeX escaped characters for non Ascii letters are converted to UTF-8, as XMP
+  LaTeX escaped characters for non ASCII letters are converted to UTF-8, as XMP
   already specifies this codec.
 
   The actual writing of the packet into the document is performed by ExifTool,
   an excellent Perl program written by Phil Harvey. See
   \htmlonly
-  <a href="https://sno.phy.queensu.ca/~phil/exiftool/" target="_blank">https://sno.phy.queensu.ca/~phil/exiftool/</a>.
+  <a href="https://exiftool.org/" target="_blank">https://exiftool.org</a>.
   \endhtmlonly
   ExifTool supports several document formats for writing. The most relevant
   here are Postscript and PDF. For PDF documents, metadata is written as an
@@ -229,8 +221,8 @@ void metadataParser::_metadataXmp(const QString& fn, const QByteArray& raw_conte
             {
                 xmls->append(c2bUtils::toQtXmlString(QString::fromUtf8(raw_contents.mid(pos, posn - pos + 19))));
                 _has_bibtex = _has_bibtex || xmls->last().contains("bibtex:");
-                _has_cb2bib = _has_cb2bib || xmls->last().contains("https://www.molspaces.com/cb2bib");
-                _has_prism = _has_prism || xmls->last().contains("http://prismstandard.org/namespaces/basic/2.0");
+                _has_cb2bib = _has_cb2bib || xmls->last().contains("www.molspaces.com/cb2bib");
+                _has_prism = _has_prism || xmls->last().contains("prismstandard.org/namespaces/basic/2.0");
                 pos = posn;
             }
             else
@@ -340,8 +332,8 @@ void metadataParser::_metadataXmpExifTool(const QString& fn, QStringList* xmls)
     {
         xmls->append(xmp);
         _has_bibtex = _has_bibtex || xmls->last().contains("bibtex:");
-        _has_cb2bib = _has_cb2bib || xmls->last().contains("https://www.molspaces.com/cb2bib");
-        _has_prism = _has_prism || xmls->last().contains("http://prismstandard.org/namespaces/basic/2.0");
+        _has_cb2bib = _has_cb2bib || xmls->last().contains("www.molspaces.com/cb2bib");
+        _has_prism = _has_prism || xmls->last().contains("prismstandard.org/namespaces/basic/2.0");
     }
 }
 
@@ -431,7 +423,7 @@ void metadataParser::_fuzzyParser(const QString& data)
         c2bUtils::debug(tr("metadataParser: Error while parsing XML packets"));
 }
 
-bool metadataParser::insertMetadata(const bibReference& ref, const QString& fn, QString* error)
+bool metadataParser::insertMetadata(const bibReference& ref, const QString& fn, QString* error, const bool has_reference)
 {
     if (error)
         error->clear();
@@ -457,8 +449,6 @@ bool metadataParser::insertMetadata(const bibReference& ref, const QString& fn,
     {
         key = bibliographicFields.at(i);
         value = ref.value(key);
-        if (value.isEmpty())
-            continue;
         if (key == "file")
             continue;
         else if (key == "id")
@@ -480,6 +470,8 @@ bool metadataParser::insertMetadata(const bibReference& ref, const QString& fn,
     QStringList arglist;
     arglist.append("-overwrite_original");
     arglist.append("-m");
+    if (has_reference)
+        arglist.append("-P");
     arglist.append("-TagsFromFile");
     arglist.append(bibtags_file);
     arglist.append("-all:all");
