@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef NETWORKQUERY_H
@@ -28,7 +28,7 @@ class networkQuery : public QObject
     Q_OBJECT
 
 public:
-    networkQuery(bibParser* bp, QObject* parento = 0);
+    explicit networkQuery(bibParser* bp, QObject* parento = 0);
     networkQuery(bibParser* bp, network* net, QObject* parento = 0);
     inline virtual ~networkQuery() {}
 
