@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef SEARCHPATTERN_H
@@ -9,10 +9,11 @@
 
 #include "approximatePattern.h"
 #include "documentContents.h"
+#include "scorer.h"
+#include "stemMatcher.h"
 #include "wordMatcher.h"
 #include "wordPattern.h"
 
-#include <QList>
 #include <QRegularExpression>
 
 
@@ -28,12 +29,13 @@ public:
     enum Type
     {
         ApproximateString = 1,
-        FixedStringAllWords = 2,
-        FixedStringAnyWord = 3,
-        FixedStringContext = 4,
-        FixedString = 5,
-        RegularExpression = 6,
-        Wildcard = 7
+        Context = 2,
+        FixedStringAllWords = 3,
+        FixedStringAnyWord = 4,
+        FixedStringContext = 5,
+        FixedString = 6,
+        RegularExpression = 7,
+        Wildcard = 8
     };
     static const QString type(const Type t);
     static const QStringList types();
@@ -70,6 +72,22 @@ public:
     {
         return _matcher.length;
     }
+    inline void initializeScores() const
+    {
+        _scorer.initialize();
+    }
+    inline void updateScore() const
+    {
+        _scorer.update(_matcher.plength, _matcher.length);
+    }
+    inline int matchedCounter() const
+    {
+        return _scorer.nscores;
+    }
+    inline double matchedScore() const
+    {
+        return _scorer.score();
+    }
     inline const QString toString() const
     {
         return _formatted_string;
@@ -87,12 +105,16 @@ private:
 
         QRegularExpression regexp;
         QString signature;
+        QString typedpattern;
         QStringMatcher strexp;
         QVector<QString> subsignatures;
+        Qt::CaseSensitivity csensitivity;
         Type type;
         approximatePattern appexp;
+        int plength;
         mutable QRegularExpressionMatch regexp_match;
         mutable int length;
+        stemMatcher cstemexp;
         wordMatcher cwordexp;
         wordPattern wordexp;
 
@@ -101,40 +123,49 @@ private:
         int index(const QString& contents, const int from) const;
 
         static QString _wildcard_escaped(const QString& pattern);
+        void _set_typed_pattern(const QString& pattern);
 
-        inline static bool _match_signature(const QString& ps, const QString& cs)
+        static inline bool _match_signature(const QString& ps, const QString& cs)
         {
             const int pl(ps.length()); // Always pl > 0
             const int cl(cs.length());
-            const ushort* ups = (const ushort*)ps.unicode();
-            const ushort* p = ups;
-            const ushort* pn = ups + pl;
-            const ushort* ucs = (const ushort*)cs.unicode();
-            const ushort* c = ucs - 1;
-            const ushort* cn = ucs + cl;
+            const ushort* ups(reinterpret_cast<const ushort*>(ps.unicode()));
+            const ushort* p(ups);
+            const ushort* pn(ups + pl);
+            const ushort* ucs(reinterpret_cast<const ushort*>(cs.unicode()));
+            const ushort* c(ucs - 1);
+            const ushort* cn(ucs + cl);
             while (++c != cn)
                 if (*c == *p)
                     if (++p == pn)
                         return true;
             return false;
         }
-        inline static bool _match(const QRegularExpression& submatcher, const QString& psignature,
+        static inline bool _match(const QRegularExpression& submatcher, const QString& psignature,
                                   const documentContents& contents)
         {
+#ifdef C2B_DEBUG_SEARCHING_SKIP_SIGNATURE
+            return submatcher.match(contents.text()).hasMatch();
+#else
             // Skip signature check for patterns that do not define it
             if (psignature.length() == 0 || _match_signature(psignature, contents.signature()))
                 return submatcher.match(contents.text()).hasMatch();
             else
                 return false;
+#endif
         }
         template <typename T>
-        inline static bool _match(const T& submatcher, const QString& psignature, const documentContents& contents)
+        static inline bool _match(const T& submatcher, const QString& psignature, const documentContents& contents)
         {
+#ifdef C2B_DEBUG_SEARCHING_SKIP_SIGNATURE
+            return submatcher.indexIn(contents.text()) != -1;
+#else
             // Skip signature check for patterns that do not define it
             if (psignature.length() == 0 || _match_signature(psignature, contents.signature()))
                 return submatcher.indexIn(contents.text()) != -1;
             else
                 return false;
+#endif
         }
         template <typename T>
         inline bool _match_all(const int n, const T& submatchers, const documentContents& contents) const
@@ -154,16 +185,17 @@ private:
         }
     };
 
+    static const QMap<QString, searchPattern::Type> typemap();
+    static inline Qt::CaseSensitivity qtcase(bool caseSensitive)
+    {
+        return caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive;
+    }
+
     QString _formatted_string;
     int _rank;
     matcher _matcher;
     modifiers _modifier;
-
-    static const QMap<QString, searchPattern::Type> typemap();
-    inline static Qt::CaseSensitivity qtcase(bool caseSensitive)
-    {
-        return caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive;
-    }
+    mutable scorer _scorer;
 };
 
 #endif
