@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "settings.h"
@@ -81,6 +81,7 @@ void settings::_init()
     _is_loaded = true;
     cl_bibedit = false;
     cl_cb2bib_import_mode = false;
+    cl_cb2bib_information = false;
     cl_cb2bib_tests = false;
     cl_citer = false;
     cl_configure = false;
@@ -184,13 +185,14 @@ void settings::setDefaults()
     defaults["cb2Bib/AutomaticPdfDownload"] = false;
     defaults["cb2Bib/AutomaticQuery"] = false;
     defaults["cb2Bib/CheckRepeatedOnSave"] = false;
+    defaults["cb2Bib/CiteCommandPattern"] = C2B_CITE_COMMAND_PATTERN;
     defaults["cb2Bib/CiteIdPattern"] = C2B_CITE_ID_PATTERN;
     defaults["cb2Bib/ConvertReferenceToLaTeX"] = true;
     defaults["cb2Bib/CopyMovePdf"] = "copy";
     defaults["cb2Bib/DoHeuristicGuess"] = true;
     defaults["cb2Bib/DocumentIdPattern"] = C2B_DOCUMENT_ID_PATTERN;
     defaults["cb2Bib/FindReplaceInput"] = true;
-    defaults["cb2Bib/FindReplaceInputList"] = C2B_FIND_REPLACE_LIST.split("^e");
+    defaults["cb2Bib/FindReplaceInputList"] = QString(C2B_FIND_REPLACE_LIST).split("^e");
     defaults["cb2Bib/InsertMetadata"] = false;
     defaults["cb2Bib/KeepTmpNQFiles"] = false;
     defaults["cb2Bib/MovePdf"] = false;
@@ -305,16 +307,17 @@ settings* settings::_c2b_global_settings = 0;
 
 */
 
-bool settings::isConsoleMode(int& argc, char** argv)
+bool settings::isConsoleMode(const int argc, char** argv)
 {
     for (int i = 0; i < argc; ++i)
         if (strcmp(argv[i], "--html-annote") == 0 || strcmp(argv[i], "--doc2bib") == 0 ||
-            strcmp(argv[i], "--txt2bib") == 0 || strcmp(argv[i], "--index") == 0 || strcmp(argv[i], "--test") == 0)
+            strcmp(argv[i], "--txt2bib") == 0 || strcmp(argv[i], "--index") == 0 || strcmp(argv[i], "--c2binfo") == 0 ||
+            strcmp(argv[i], "--test") == 0)
             return true;
     return false;
 }
 
-bool settings::isSingleApplicationMode(int& argc, char** argv)
+bool settings::isSingleApplicationMode(const int argc, char** argv)
 {
     for (int i = 0; i < argc; ++i)
         if (strcmp(argv[i], "--citer") == 0)
@@ -421,6 +424,8 @@ void settings::readCommandLine()
                 checkCommand(&cl_txt2bib, &actions);
             else if (arguments.at(i) == "--index")
                 checkCommand(&cl_index, &actions);
+            else if (arguments.at(i) == "--c2binfo")
+                cl_cb2bib_information = true;
             else if (arguments.at(i).startsWith("--test"))
                 cl_cb2bib_tests = true;
             else
@@ -440,7 +445,8 @@ void settings::readCommandLine()
         printUsage();
         return;
     }
-    cl_console_mode = cl_html_annote || cl_cb2bib_tests || cl_doc2bib || cl_txt2bib || cl_index;
+    cl_console_mode =
+        cl_html_annote || cl_cb2bib_information || cl_cb2bib_tests || cl_doc2bib || cl_txt2bib || cl_index;
     cl_cb2bib_mode = !(cl_console_mode || cl_configure || cl_view_annote);
 
     // Check for cl_user_configured
