@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "substringMatcher.h"
@@ -34,7 +34,7 @@ substringMatcher::substringMatcher(const QString& pattern, const Qt::CaseSensiti
     _lengths.resize(_substring_count);
     for (int i = 0; i < _substring_count; ++i)
     {
-        _substrings[i] = QStringMatcher(substrings.at(i), cs);
+        _substrings[i] = txtmatcher(substrings.at(i), cs);
         _lengths[i] = substrings.at(i).length();
     }
     _stretches.resize(_substring_count);
@@ -56,8 +56,8 @@ substringMatcher::substringMatcher(const QString& pattern, const Qt::CaseSensiti
         }
     }
 #if C2B_DEBUG_SUBSTRINGMATCHER
-    qDebug() << "Pattern:" << pattern;
-    qDebug() << "Hook:" << substrings.at(_hook);
+    qDebug() << "substringMatcher: Pattern: " << pattern;
+    qDebug() << "substringMatcher: Hook:    " << substrings.at(_hook);
 #endif
 }
 
@@ -65,11 +65,8 @@ substringMatcher::substringMatcher(const QString& pattern, const Qt::CaseSensiti
 int substringMatcher::indexIn(const QString& str, const int from) const
 {
     _matched_length = -1;
-    if (_hook == -1)
-    {
-        c2bUtils::warn(QObject::tr("Warning: Uninitialized substringMatcher"));
+    if (_hook == -1) // Uninitialized
         return -1;
-    }
     _p0 = from;
     if (_p0 < 0)
         _p0 = 0;
@@ -83,7 +80,7 @@ int substringMatcher::indexIn(const QString& str, const int from) const
     {
         hp = _index_in(_hook, str, hp + _acc_lengths.at(_hook));
 #if C2B_DEBUG_SUBSTRINGMATCHER
-        qDebug() << "Hook at" << hp;
+        qDebug() << "substringMatcher: Hook at  " << hp;
 #endif
         if (hp == -1)
             return -1;
