@@ -1,13 +1,14 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef SUBSTRINGMATCHER_H
 #define SUBSTRINGMATCHER_H
 
-#include <QStringMatcher>
+#include "txtmatcher.h"
+
 #include <QVector>
 
 #define C2B_DEBUG_SUBSTRINGMATCHER 0
@@ -18,7 +19,7 @@ class substringMatcher
 
 public:
     substringMatcher();
-    substringMatcher(const QString& pattern, const Qt::CaseSensitivity cs = Qt::CaseSensitive);
+    explicit substringMatcher(const QString& pattern, const Qt::CaseSensitivity cs = Qt::CaseSensitive);
     inline ~substringMatcher() {}
 
 
@@ -30,11 +31,11 @@ public:
 
 
 private:
-    inline int _index_in(const int& s, const QString& str, const int& p0) const
+    inline int _index_in(const int s, const QString& str, const int p0) const
     {
         return _substrings.at(s).indexIn(str, p0);
     }
-    inline int _index_in(const int& s, const QString& str, const int& p0, const int& pn) const
+    inline int _index_in(const int s, const QString& str, const int p0, const int pn) const
     {
 #if C2B_DEBUG_SUBSTRINGMATCHER
         qDebug() << "Search for substring:" << _substrings.at(s).pattern() << "in interval" << p0 << pn;
@@ -43,11 +44,9 @@ private:
             i = -1;
         else
             i = _substrings.at(s).indexIn(str.unicode(), std::min(_pn, pn), p0);
-        qDebug() << "Returned index:" << i;
+        qDebug() << "substringMatcher: returned index:" << i;
         return i;
 #else
-        if (p0 >= pn)
-            return -1;
         return _substrings.at(s).indexIn(str.unicode(), std::min(_pn, pn), p0);
 #endif
     }
@@ -106,7 +105,7 @@ private:
         return bp;
     }
 
-    QVector<QStringMatcher> _substrings;
+    QVector<txtmatcher> _substrings;
     QVector<int> _acc_lengths;
     QVector<int> _lengths;
     QVector<int> _stretches;
