@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "texToHtml.h"
@@ -207,7 +207,7 @@ void texToHtml::extractMacro(const QString& v)
     _tex_macro_names_rx.append(QRegExp("(\\" + name + "\\S*)"));
     // To minimize clashes, the replacement must be performed from longest to shortest names.
     // Sort now, even if this needs multiple sortings. This way, substitutions can be done while parsing.
-    qSort(_tex_macro_names_rx.begin(), _tex_macro_names_rx.end(), c2bUtils::patternLengthMoreThan);
+    std::sort(_tex_macro_names_rx.begin(), _tex_macro_names_rx.end(), c2bUtils::patternLengthMoreThan);
     QString definition;
     for (int i = name.length() + 2; i < v.length(); ++i)
         if (v.at(i) == '{')
@@ -355,10 +355,10 @@ void texToHtml::referencesToHtml(QString* reference_list_html)
             link = url;
         else if (!doi.isEmpty())
         {
-            if (doi.startsWith("http://"))
+            if (doi.startsWith("http"))
                 link = doi;
             else
-                link = "http://dx.doi.org/" + QUrl::toPercentEncoding(doi);
+                link = "https://dx.doi.org/" + QUrl::toPercentEncoding(doi);
         }
 
         const QString journal(ref.anyJournal());
