@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "triads.h"
@@ -32,31 +32,30 @@ const QString triads::asciiTextSignature(const QString& str)
     QString s(str);
     s.replace(c2bUtils::nonAsciiLetter, " ");
     s = s.toLower();
-    s = c2bUtils::simplifyString(s);
 
     const int nletters(26);
     const int ngram(5);
     const int slength(s.length());
     const int code0(QChar('a').unicode());
+    const QChar space(' ');
 
-    QHash<int, int> triads;
+    QSet<int> triads;
     for (int i = 0; i <= slength - ngram; ++i)
     {
-        const QString t(s.mid(i, ngram));
-        if (t.contains(' '))
+        if (s.midRef(i, ngram).contains(space))
             continue;
-        int t1 = s.at(i).unicode() - code0;
-        int t2 = s.at(i + 2).unicode() - code0;
-        int t3 = s.at(i + 4).unicode() - code0;
-        int code = code0 + t1 * nletters * nletters + t2 * nletters + t3;
+        const int t1(s.at(i).unicode() - code0);
+        const int t2(s.at(i + 2).unicode() - code0);
+        const int t3(s.at(i + 4).unicode() - code0);
+        const int code(code0 + t1 * nletters * nletters + t2 * nletters + t3);
         if (!triads.contains(code))
-            triads.insert(code, 1);
+            triads.insert(code);
     }
-    QList<int> codes(triads.keys());
-    qSort(codes);
-    s.clear();
+    QList<int> codes(triads.toList());
+    std::sort(codes.begin(), codes.end());
+    s.resize(codes.count());
     for (int i = 0; i < codes.count(); ++i)
-        s += QChar(codes.at(i));
+        s[i] = QChar(codes.at(i));
     return s;
 }
 
@@ -94,7 +93,7 @@ int triads::_rank(const QString& str, const QString& sign, const QString& ranks)
     int j0(0);
     for (int i = 0; i < m; ++i)
         for (int j = j0; j < n; ++j)
-            if (sign[i] == ranks[j])
+            if (sign.at(i) == ranks.at(j))
             {
                 ++counter;
                 j0 = j + 1;
