@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef WORDPATTERN_H
@@ -9,8 +9,7 @@
 
 #include "compositePattern.h"
 
-
-#include <QStringMatcher>
+#include "txtmatcher.h"
 
 
 class wordPattern : public compositePattern
@@ -52,32 +51,18 @@ public:
     }
     inline int indexIn(const QString& str, const int from = 0) const override
     {
-        // Do not match. Get index for (w1|w2|...).
-        _matched_length = -1;
-        if (str.length() == 0)
-            return -1;
-        int index(str.length());
-        for (int i = 0; i < _subpattern_count; ++i)
-        {
-            const int p(_submatchers.at(i).indexIn(str, from));
-            if (p != -1 && p < index)
-            {
-                index = p;
-                _matched_length = _substrings.at(i).length();
-            }
-        }
-        if (index == str.length())
-            index = -1;
-        return index;
+        const QRegularExpressionMatch rem(_regexp.match(str, from));
+        _matched_length = rem.capturedLength();
+        return rem.capturedStart();
     }
-    inline const QVector<QStringMatcher>& submatchers() const
+    inline const QVector<txtmatcher>& submatchers() const
     {
         return _submatchers;
     }
 
 
 private:
-    QVector<QStringMatcher> _submatchers;
+    QVector<txtmatcher> _submatchers;
     Type _type;
 };
 
