@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BCITEREXCERPTVIEW_H
@@ -20,7 +20,7 @@ class c2bCiterExcerptView : public QDialog
     Q_OBJECT
 
 public:
-    c2bCiterExcerptView(const QString& html, QWidget* parentw = 0);
+    explicit c2bCiterExcerptView(const QString& html, QWidget* parentw = 0);
     ~c2bCiterExcerptView();
 
 
