@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bCiterModel.h"
@@ -13,6 +13,8 @@
 #include <QDateTime>
 #include <QIcon>
 
+namespace
+{
 
 template <typename T>
 class ascending
@@ -28,6 +30,8 @@ private:
     const T& _data;
 };
 
+} // namespace
+
 
 c2bCiterModel::c2bCiterModel(QObject* parento) : QAbstractTableModel(parento)
 {
@@ -298,7 +302,7 @@ QList<int> c2bCiterModel::sizeHintForColumns() const
     switch (_format)
     {
     case c2bCiter::AJYT:
-        sizes.append(qMin(20, _author_max_length + 2));
+        sizes.append(std::min(20, _author_max_length + 2));
         sizes.append(20);
         sizes.append(6);
         sizes.append(100);
@@ -308,7 +312,7 @@ QList<int> c2bCiterModel::sizeHintForColumns() const
         sizes.append(100);
         break;
     case c2bCiter::JYA:
-        sizes.append(qMin(25, _journal_max_length));
+        sizes.append(std::min(25, _journal_max_length));
         sizes.append(6);
         sizes.append(100);
         break;
@@ -582,10 +586,10 @@ void c2bCiterModel::_add_citations(const QString& fn)
             const QString doi(ref.value(tag_doi));
             if (!doi.isEmpty())
             {
-                if (doi.startsWith("http://"))
+                if (doi.startsWith("http"))
                     url = QUrl::toPercentEncoding(doi);
                 else
-                    url = "http://dx.doi.org/" + QUrl::toPercentEncoding(doi);
+                    url = "https://dx.doi.org/" + QUrl::toPercentEncoding(doi);
             }
         }
 
@@ -677,7 +681,7 @@ void c2bCiterModel::_set_table_data()
         {
             _author[ij] = authors.at(j).trimmed();
             _map_author[ij] = i;
-            _author_max_length = qMax(_author_max_length, _author.at(ij).length());
+            _author_max_length = std::max(_author_max_length, _author.at(ij).length());
             ++ij;
         }
     }
@@ -689,7 +693,7 @@ void c2bCiterModel::_set_table_data()
     {
         _journal[i] = bpP->abbreviatedJournal(_journal.at(i));
         _journal[i].remove(dot);
-        _journal_max_length = qMax(_journal_max_length, _journal.at(i).length());
+        _journal_max_length = std::max(_journal_max_length, _journal.at(i).length());
     }
 
     _is_selected.resize(_citation_count);
@@ -697,8 +701,8 @@ void c2bCiterModel::_set_table_data()
         _is_selected[i] = false;
 
     _keyword_count = _analyzer.sentenceCount();
-    const int mca(qMax(_citation_count, _author_count));
-    const int mcas(qMax(mca, _keyword_count));
+    const int mca(std::max(_citation_count, _author_count));
+    const int mcas(std::max(mca, _keyword_count));
     _matches_filter.resize(mca);
     _map_filter.resize(mcas);
 }
@@ -720,7 +724,7 @@ void c2bCiterModel::_set_sort_indices()
     for (int i = 0; i < _author_count; ++i)
         _map_ajyt[i] = i;
     ascending<QVector<QString>> ajyt(_search_string);
-    qSort(_map_ajyt.begin(), _map_ajyt.end(), ajyt);
+    std::sort(_map_ajyt.begin(), _map_ajyt.end(), ajyt);
 
     // IT
     _search_string.resize(_citation_count);
@@ -734,7 +738,7 @@ void c2bCiterModel::_set_sort_indices()
     for (int i = 0; i < _citation_count; ++i)
         _map_it[i] = i;
     ascending<QVector<QString>> it(_search_string);
-    qSort(_map_it.begin(), _map_it.end(), it);
+    std::sort(_map_it.begin(), _map_it.end(), it);
 
     // JYA
     for (int i = 0; i < _citation_count; ++i)
@@ -744,7 +748,7 @@ void c2bCiterModel::_set_sort_indices()
     for (int i = 0; i < _citation_count; ++i)
         _map_jya[i] = i;
     ascending<QVector<QString>> jya(_search_string);
-    qSort(_map_jya.begin(), _map_jya.end(), jya);
+    std::sort(_map_jya.begin(), _map_jya.end(), jya);
 
     // T
     for (int i = 0; i < _citation_count; ++i)
@@ -753,7 +757,7 @@ void c2bCiterModel::_set_sort_indices()
     for (int i = 0; i < _citation_count; ++i)
         _map_t[i] = i;
     ascending<QVector<QString>> t(_search_string);
-    qSort(_map_t.begin(), _map_t.end(), t);
+    std::sort(_map_t.begin(), _map_t.end(), t);
 
     // YAJT
     for (int i = 0; i < _citation_count; ++i)
@@ -763,7 +767,7 @@ void c2bCiterModel::_set_sort_indices()
     for (int i = 0; i < _citation_count; ++i)
         _map_yajt[i] = i;
     ascending<QVector<QString>> yajt(_search_string);
-    qSort(_map_yajt.begin(), _map_yajt.end(), yajt);
+    std::sort(_map_yajt.begin(), _map_yajt.end(), yajt);
     // Keep _search_string for filtering
 }
 
