@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bCiterView.h"
@@ -221,7 +221,11 @@ void c2bCiterView::updateViewport()
         return;
     }
     QList<int> w = _citationsP->sizeHintForColumns();
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+    const int char_w(fontMetrics().horizontalAdvance(QLatin1Char('N')));
+#else
     const int char_w(fontMetrics().width(QLatin1Char('N')));
+#endif
     for (int i = 0; i < nc; ++i)
         w[i] *= char_w;
     int required_w(w.at(0));
