@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BCLIPEDIT_H
@@ -25,7 +25,7 @@ public:
         Browser
     };
 
-    c2bClipEdit(const Mode mode, QWidget* parentw = 0);
+    explicit c2bClipEdit(const Mode mode, QWidget* parentw = 0);
     ~c2bClipEdit();
 
     void setText(const QString& text, const QString& tagged_text = QString());
