@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bColors.h"
@@ -50,17 +50,17 @@ void c2bColors::saveColors(c2bSettings* settings)
 
 void c2bColors::loadColors(c2bSettings* settings)
 {
-    bib_delimiter_color = settings->value("c2bColors/bib_delimiter_color", "#A9A9A9").value<QColor>();
-    bib_reference_field_color = settings->value("c2bColors/bib_reference_field_color", "#FFE66A").value<QColor>();
-    bib_reference_type_color = settings->value("c2bColors/bib_reference_type_color", "#5EB7F7").value<QColor>();
-    cb2bib_digit_color = settings->value("c2bColors/cb2bib_digit_color", "#39C9FD").value<QColor>();
-    cb2bib_highly_relevant_color = settings->value("c2bColors/cb2bib_highly_relevant_color", "#00FD00").value<QColor>();
-    cb2bib_metadata_color = settings->value("c2bColors/cb2bib_metadata_color", "#FFE66A").value<QColor>();
-    cb2bib_relevant_color = settings->value("c2bColors/cb2bib_relevant_color", "#008B8B").value<QColor>();
-    cb2bib_tag_color = settings->value("c2bColors/cb2bib_tag_color", "#5AF7F4").value<QColor>();
-    cb2bib_unrelevant_color = settings->value("c2bColors/cb2bib_unrelevant_color", "#868374").value<QColor>();
-    comment_color = settings->value("c2bColors/comment_color", "#A5A5A5").value<QColor>();
+    bib_delimiter_color = settings->value("c2bColors/bib_delimiter_color", "#555555").value<QColor>();
+    bib_reference_field_color = settings->value("c2bColors/bib_reference_field_color", "#00007f").value<QColor>();
+    bib_reference_type_color = settings->value("c2bColors/bib_reference_type_color", "#00007f").value<QColor>();
+    cb2bib_digit_color = settings->value("c2bColors/cb2bib_digit_color", "#005500").value<QColor>();
+    cb2bib_highly_relevant_color = settings->value("c2bColors/cb2bib_highly_relevant_color", "#0000ff").value<QColor>();
+    cb2bib_metadata_color = settings->value("c2bColors/cb2bib_metadata_color", "#595942").value<QColor>();
+    cb2bib_relevant_color = settings->value("c2bColors/cb2bib_relevant_color", "#005500").value<QColor>();
+    cb2bib_tag_color = settings->value("c2bColors/cb2bib_tag_color", "#550000").value<QColor>();
+    cb2bib_unrelevant_color = settings->value("c2bColors/cb2bib_unrelevant_color", "#595942").value<QColor>();
+    comment_color = settings->value("c2bColors/comment_color", "#595942").value<QColor>();
     netqinf_command_content_color =
-        settings->value("c2bColors/netqinf_command_content_color", "#FFFFFF").value<QColor>();
-    netqinf_command_key_color = settings->value("c2bColors/netqinf_command_key_color", "#D5A805").value<QColor>();
+        settings->value("c2bColors/netqinf_command_content_color", "#000000").value<QColor>();
+    netqinf_command_key_color = settings->value("c2bColors/netqinf_command_key_color", "#00007f").value<QColor>();
 }
