@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bConsole.h"
@@ -44,6 +44,8 @@ void c2bConsole::_process()
         code = cl_index();
     else if (c2bSettingsP->cl_cb2bib_tests)
         code = cl_cb2bib_tests();
+    else if (c2bSettingsP->cl_cb2bib_information)
+        code = cl_cb2bib_information();
     QCoreApplication::exit(code);
 }
 
@@ -94,9 +96,17 @@ int c2bConsole::cl_index()
     return c;
 }
 
+int c2bConsole::cl_cb2bib_information()
+{
+    c2bTests* t(new c2bTests());
+    const int passed(t->writeInformation());
+    delete t;
+    return passed;
+}
+
 int c2bConsole::cl_cb2bib_tests()
 {
-    c2bTests* t = new c2bTests();
+    c2bTests* t(new c2bTests());
     const int passed(t->allTests());
     delete t;
     return passed;
