@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *
  *   The LyX pipe procedure in citeToLyXPipe has been adapted from Tellico
@@ -31,32 +31,58 @@ c2bCoreCiter::c2bCoreCiter(QWidget* parentw) : QObject(parentw)
     _settingsP->setDefaultValue("c2bCoreCiter/LyXPipe",
                                 QDir::cleanPath(QDir::homePath() + QDir::separator() + ".lyx/lyxpipe.in"));
     _lyxpipe = _settingsP->value("c2bCoreCiter/LyXPipe").toString();
+
+    _citeids = QRegExp("^([^<]*)<<([^\\|]*)\\|citeids\\|([^>]*)>>(.*)$");
 }
 
 c2bCoreCiter::~c2bCoreCiter() {}
 
 
-void c2bCoreCiter::cite(const QStringList& keys) const
+void c2bCoreCiter::cite(const QStringList& keys)
 {
-    QByteArray pipe = QFile::encodeName(_lyxpipe);
-    if (QFile::exists(pipe))
-        citeToLyXPipe(keys);
+    if (keys.count() == 0)
+        return;
+
+    _command = _settingsP->value("cb2Bib/CiteCommandPattern").toString();
+    const QByteArray pipe(QFile::encodeName(_lyxpipe));
+    if (QFile::exists(pipe) && _command == C2B_CITE_COMMAND_PATTERN)
+        _cite_to_lyx_pipe(keys);
     else
-        citeToClipboard(keys);
+        _cite_to_clipboard(keys);
 }
 
-void c2bCoreCiter::citeToClipboard(const QStringList& keys) const
+void c2bCoreCiter::_cite_to_clipboard(const QStringList& keys) const
 {
-    const QString c("\\cite{" + keys.join(", ").trimmed() + '}');
-    QClipboard* cb = QApplication::clipboard();
-    cb->setText(c, QClipboard::Clipboard);
+    QString c;
+    if (_command.isEmpty() || _command == C2B_CITE_COMMAND_PATTERN)
+        c = QLatin1String("\\cite{") + keys.join(QLatin1String(", ")).trimmed() + QLatin1Char('}');
+    else if (_command.contains(QLatin1String("<<citeid>>")))
+        for (int i = 0; i < keys.count(); ++i)
+            c += QString(_command).replace(QLatin1String("<<citeid>>"), keys.at(i)) + QLatin1Char(' ');
+    else if (_citeids.indexIn(_command) >= 0)
+    {
+        c = _citeids.cap(2) + keys.at(0); // Note keys.count() > 0
+        for (int i = 1; i < keys.count(); ++i)
+            c += _citeids.cap(3) + QLatin1Char(' ') + _citeids.cap(2) + keys.at(i);
+        c = _citeids.cap(1) + c.trimmed() + _citeids.cap(4);
+    }
+
+    if (c.isEmpty())
+    {
+        QMessageBox::warning(_parentWP, tr("Warning - cb2Bib"), tr("Cite Command Pattern is misspecified"),
+                             QMessageBox::Ok);
+        return;
+    }
+
+    QClipboard* cb(QApplication::clipboard());
+    cb->setText(c.trimmed(), QClipboard::Clipboard);
 }
 
-void c2bCoreCiter::citeToLyXPipe(const QStringList& keys) const
+void c2bCoreCiter::_cite_to_lyx_pipe(const QStringList& keys) const
 {
     // This procedure was adapted from Tellico
     // Tellico (C) 2003-2005 by Robby Stephenson
-    QByteArray pipe = QFile::encodeName(_lyxpipe);
+    const QByteArray pipe(QFile::encodeName(_lyxpipe));
     const QString errorStr(tr("Unable to write to the server pipe at '%1'.").arg(QString(pipe)));
 
     if (!QFile::exists(pipe))
