@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BCORECITER_H
@@ -23,9 +23,7 @@ public:
     explicit c2bCoreCiter(QWidget* parentw = 0);
     ~c2bCoreCiter();
 
-    void cite(const QStringList& keys) const;
-    void citeToClipboard(const QStringList& keys) const;
-    void citeToLyXPipe(const QStringList& keys) const;
+    void cite(const QStringList& keys);
 
 
 public slots:
@@ -33,6 +31,11 @@ public slots:
 
 
 private:
+    void _cite_to_clipboard(const QStringList& keys) const;
+    void _cite_to_lyx_pipe(const QStringList& keys) const;
+
+    QRegExp _citeids;
+    QString _command;
     QString _lyxpipe;
     QWidget* _parentWP;
     settings* _settingsP;
