@@ -1,15 +1,13 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bFileDialog.h"
 #include "c2bSettings.h"
 
-#include <QDialogButtonBox>
 #include <QLineEdit>
-#include <QPushButton>
 #include <QTimer>
 
 
@@ -28,9 +26,9 @@ c2bFileDialog::~c2bFileDialog() {}
 
 QString c2bFileDialog::getFilename(QWidget* parentw, const QString& caption, const QString& path, const QString& filter)
 {
-    c2bFileDialog* dlg = new c2bFileDialog(parentw, _caption(tr("Select a filename"), caption), _path(path), filter);
-    dlg->setConfirmOverwrite(false);
+    c2bFileDialog* dlg(new c2bFileDialog(parentw, _caption(tr("Select a filename"), caption), _path(path), filter));
     dlg->setFileMode(AnyFile);
+    dlg->setOption(QFileDialog::DontConfirmOverwrite, true);
     dlg->setAcceptMode(AcceptSave);
     dlg->setLabelText(QFileDialog::Accept, "Select");
     const QString fn(dlg->fileName(path));
@@ -41,7 +39,7 @@ QString c2bFileDialog::getFilename(QWidget* parentw, const QString& caption, con
 QString c2bFileDialog::getOpenFilename(QWidget* parentw, const QString& caption, const QString& path,
                                        const QString& filter)
 {
-    c2bFileDialog* dlg = new c2bFileDialog(parentw, _caption(tr("Select a filename"), caption), _path(path), filter);
+    c2bFileDialog* dlg(new c2bFileDialog(parentw, _caption(tr("Select a filename"), caption), _path(path), filter));
     dlg->setFileMode(ExistingFile);
     dlg->setLabelText(QFileDialog::Accept, "Select");
     const QString fn(dlg->fileName(path));
@@ -52,7 +50,7 @@ QString c2bFileDialog::getOpenFilename(QWidget* parentw, const QString& caption,
 QStringList c2bFileDialog::getOpenFilenames(QWidget* parentw, const QString& caption, const QString& path,
         const QString& filter)
 {
-    c2bFileDialog* dlg = new c2bFileDialog(parentw, _caption(tr("Select filenames"), caption), _path(path), filter);
+    c2bFileDialog* dlg(new c2bFileDialog(parentw, _caption(tr("Select filenames"), caption), _path(path), filter));
     dlg->setFileMode(ExistingFiles);
     dlg->setLabelText(QFileDialog::Accept, "Select");
     const QString fn(dlg->fileName(path));
@@ -66,7 +64,7 @@ QStringList c2bFileDialog::getOpenFilenames(QWidget* parentw, const QString& cap
 QString c2bFileDialog::getSaveFilename(QWidget* parentw, const QString& caption, const QString& path,
                                        const QString& filter)
 {
-    c2bFileDialog* dlg = new c2bFileDialog(parentw, _caption(tr("Save As"), caption), _path(path), filter);
+    c2bFileDialog* dlg(new c2bFileDialog(parentw, _caption(tr("Save As"), caption), _path(path), filter));
     dlg->setFileMode(AnyFile);
     dlg->setAcceptMode(AcceptSave);
     const QString fn(dlg->fileName(path));
@@ -76,8 +74,9 @@ QString c2bFileDialog::getSaveFilename(QWidget* parentw, const QString& caption,
 
 QString c2bFileDialog::getExistingDirectory(QWidget* parentw, const QString& caption, const QString& path)
 {
-    c2bFileDialog* dlg = new c2bFileDialog(parentw, _caption("Select directory", caption), _dirpath(path), QString());
-    dlg->setFileMode(DirectoryOnly);
+    c2bFileDialog* dlg(new c2bFileDialog(parentw, _caption("Select directory", caption), _dirpath(path), QString()));
+    dlg->setFileMode(Directory);
+    dlg->setOption(QFileDialog::ShowDirsOnly, true);
     dlg->setLabelText(QFileDialog::Accept, "Select");
     const QString fn(dlg->fileName(QString()));
     delete dlg;
@@ -87,11 +86,11 @@ QString c2bFileDialog::getExistingDirectory(QWidget* parentw, const QString& cap
 QString c2bFileDialog::getSystemFilename(QWidget* parentw, const QString& caption, const QString& path,
         const QString& filter)
 {
-    c2bFileDialog* dlg = new c2bFileDialog(parentw, _caption(tr("Select a filename"), caption), _path(path), filter);
+    c2bFileDialog* dlg(new c2bFileDialog(parentw, _caption(tr("Select a filename"), caption), _path(path), filter));
     dlg->setFileMode(AnyFile);
     dlg->setLabelText(QFileDialog::Accept, "Select");
     dlg->setFilter(QDir::Drives | QDir::AllDirs | QDir::NoDotAndDotDot | QDir::System);
-    dlg->setNameFilterDetailsVisible(false);
+    dlg->setOption(QFileDialog::HideNameFilterDetails, true);
     const QString fn(dlg->fileName(path));
     delete dlg;
     return fn;
@@ -150,10 +149,10 @@ void c2bFileDialog::readSettings()
     resize(settings->value("c2bFileDialog/size", sizeHint()).toSize());
 
     // History
-    QStringList _history(settings->value("c2bFileDialog/history").toStringList());
-    _history.removeAll(directory().absolutePath());
-    qSort(_history);
-    setHistory(_history);
+    QStringList dhistory(settings->value("c2bFileDialog/history").toStringList());
+    dhistory.removeAll(directory().absolutePath());
+    std::sort(dhistory.begin(), dhistory.end());
+    setHistory(dhistory);
 }
 
 void c2bFileDialog::writeSettings()
@@ -165,22 +164,22 @@ void c2bFileDialog::writeSettings()
     if (result() == QDialog::Accepted)
     {
         // Unique paths, keeping the newest history entries
-        QStringList _history(history());
-        _history.append(directory().absolutePath());
-        _history.removeAll(QDir::homePath());
-        _history.removeAll(QDir::rootPath());
+        QStringList dhistory(history());
+        dhistory.append(directory().absolutePath());
+        dhistory.removeAll(QDir::homePath());
+        dhistory.removeAll(QDir::rootPath());
         QStringList chronological(settings->value("c2bFileDialog/history").toStringList());
-        chronological.append(_history.last());
+        chronological.append(dhistory.last());
         // Discard repeated
-        _history.clear();
+        dhistory.clear();
         for (int i = chronological.count() - 1; i > -1; --i)
-            if (!_history.contains(chronological.at(i)))
+            if (!dhistory.contains(chronological.at(i)))
             {
-                _history.prepend(chronological.at(i));
-                if (_history.count() > 10)
+                dhistory.prepend(chronological.at(i));
+                if (dhistory.count() > 10)
                     break;
             }
-        settings->setValue("c2bFileDialog/history", _history);
+        settings->setValue("c2bFileDialog/history", dhistory);
     }
 }
 
