@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bPdfImport.h"
@@ -48,11 +48,11 @@
 
   At this point users can interact and supervise their references, right before
   saving them. Allowing user intervention is and has been a design goal in
-  cb2Bib. Thus, at this point, cb2Bib helps users to check their references.
-  Poorly translated characters, accented letters, 'forgotten' words, or some
-  minor formatting in the titles might be worth considering. See
+  cb2Bib. Therefore, at this point, cb2Bib helps users to check their
+  references. Poorly translated characters, accented letters, 'forgotten'
+  words, or some minor formatting in the titles might be worth considering. See
     \htmlonly
-    <a href="http://www.glyphandcog.com/textext.html" target="_blank">Glyph & Cog's Text Extraction</a>
+    <a href="https://www.glyphandcog.com/textext.html" target="_blank">Glyph & Cog's Text Extraction</a>
     \endhtmlonly
   for a description on the intricacies of PDF to text conversions. In addition,
   if too few fields were extracted, one might perform a network query. Say,
@@ -160,10 +160,9 @@
     to their corresponding bibliographic fields. Furthermore, publishers most
     often misuse these three keys, placing, for instance, DOI in title, or
     setting author to, perhaps, the document typesetter. Only BibTeX XMP
-    metadata is considered reliable, and only documents already processed with
-    cb2Bib or JabRef will have it. If you consider that a set of PDF files does
-    contain reliable data, you may force to accept it using the command line
-    switch <tt>--sloppy</tt> together with <tt>--doc2bib</tt>.
+    metadata is considered reliable. If you consider that a set of PDF files
+    does contain reliable data, you may force to accept it using the command
+    line switch <tt>--sloppy</tt> together with <tt>--doc2bib</tt>.
 
   - <b>How successful is automatic extraction?</b>\n
     As it follows from the given definition of reliable data, running automatic
@@ -179,11 +178,11 @@
     consistency across your BibTeX database. In general, do not write regular
     expressions to extract directly from the PDF text. Conversion is often
     poor. Special characters often break lines, thus breaking your regular
-    expressions too. Write customized queries. For instance, if your PDFs have
-    DOI in title page, set the simple query
+    expressions too. Write customized queries instead. For instance, if your
+    PDFs have DOI in title page, set the simple query
 \verbatim
 journal=The Journal of Everything|
-query=http://dx.doi.org/<<doi>>
+query=https://dx.doi.org/<<doi>>
 capture_from_query=
 referenceurl_prefix=
 referenceurl_sufix=
@@ -216,6 +215,7 @@ action=htm2txt_query
     algorithms may drop author middle names if a given author has 'too many
     names'. Expect convenience over accuracy on other sources.
 
+
   - <b>Can I use cb2Bib to extract comma separated value CSV references?</b>\n
     Yes. To automatically import multiple CSV references you will need one
     regular expression. If you can control CSV export, choose | as separator,
@@ -250,7 +250,7 @@ c2bPdfImport::c2bPdfImport(QWidget* parentw) : QDialog(parentw)
     loadSettings();
 
     buttonSelectFiles = new QPushButton(tr("&Select Files"));
-    buttonSelectFiles->setStatusTip(tr("Select PDF files. Hint: Files can also be dragged and dropped to this window"));
+    buttonSelectFiles->setStatusTip(tr("Select PDF files. Hint: Files can be dragged and dropped to this window"));
     buttonSelectFiles->setMouseTracking(true);
     ui.buttonBox->addButton(buttonSelectFiles, QDialogButtonBox::ActionRole);
     buttonProcess = new QPushButton(tr("&Process"));
