@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bReferenceList.h"
@@ -182,7 +182,7 @@ c2bReferenceList::~c2bReferenceList() {}
 void c2bReferenceList::loadList(const QString& txt, bibSearcher* searcher)
 {
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-    c2bBibParser* bpP = c2b::bibParser();
+    c2bBibParser* bpP(c2b::bibParser());
     QString references_html(_references_html);
     QString references;
 
@@ -208,8 +208,6 @@ void c2bReferenceList::loadList(const QString& txt, bibSearcher* searcher)
 
     while (bpP->referencesIn(txt, &ref))
     {
-        ref_counter++;
-
         QString author(ref.anyAuthor());
         QString author_long;
         if (!author.isEmpty())
@@ -231,8 +229,8 @@ void c2bReferenceList::loadList(const QString& txt, bibSearcher* searcher)
 
         QString doi(ref.value("doi"));
         if (!doi.isEmpty())
-            if (!doi.startsWith("http://"))
-                doi = "http://dx.doi.org/" + QUrl::toPercentEncoding(doi);
+            if (!doi.startsWith("http"))
+                doi = "https://dx.doi.org/" + QUrl::toPercentEncoding(doi);
 
         const QString file(ref.value("file"));
         const QString url(ref.value("url"));
@@ -245,7 +243,7 @@ void c2bReferenceList::loadList(const QString& txt, bibSearcher* searcher)
             link = doi;
 
         QString ID;
-        ID.setNum(ref_counter);
+        ID.setNum(ref_counter + 1);
         QString year(ref.value("year"));
         const QString abstract(ref.value("abstract"));
         const QString journal(ref.anyJournal());
@@ -262,7 +260,7 @@ void c2bReferenceList::loadList(const QString& txt, bibSearcher* searcher)
         dataList.append(journal);
         dataList.append(author);
         dataList.append(title);
-        TreeWidgetItem* qi = new TreeWidgetItem(dataList);
+        TreeWidgetItem* qi(new TreeWidgetItem(dataList));
         qi->setStatusTip(_journal_index, bpP->fullJournal(journal));
         qi->setStatusTip(_author_index, author_long);
         qi->setStatusTip(_title_index, title);
@@ -290,12 +288,21 @@ void c2bReferenceList::loadList(const QString& txt, bibSearcher* searcher)
         bib_item_html.replace("GET_REFERENCE_VOLUME", volume);
         bib_item_html.replace("GET_REFERENCE_YEAR", year);
         if (searcher)
-            bib_item_html.replace("GET_REFERENCE_ABSTRACT",
-                                  searcher->highlight(abstract) + searcher->hitValue(ref.rawReference));
+        {
+            if (searcher->isSearchSimilar())
+                bib_item_html.replace("GET_REFERENCE_ABSTRACT",
+                                      c2bUtils::toHtmlString(abstract) + searcher->hitHtmlDatum(ref_counter));
+            else
+                bib_item_html.replace("GET_REFERENCE_ABSTRACT",
+                                      searcher->hitHtmlAbstract(ref_counter) + searcher->hitHtmlDatum(ref_counter));
+        }
         else
             bib_item_html.replace("GET_REFERENCE_ABSTRACT", c2bUtils::toHtmlString(abstract));
         references += bib_item_html;
+        ++ref_counter;
     }
+    if (searcher && ref_counter != searcher->hitsCount())
+        c2bUtils::warn(tr("Mismatch while loading searched references"));
 
     ui.listView->sortItems(ui.listView->sortColumn(), ui.listView->header()->sortIndicatorOrder());
     ui.listView->resizeColumnToContents(_year_index);
@@ -481,7 +488,7 @@ void c2bReferenceList::goToReference(const int position)
     // Maps position to internal reference id. It is needed by the search browser, when a
     // citation is edited in the original file. If this file is changed multiple times,
     // positions in the search browser get outdated, so the mapping position-id is inexact.
-    // Thus, search for the closet reference.
+    // Thus, search for the closest reference.
     int ip(0);
     int pdiff_min(1000000);
     for (int i = 0; i < _positionList.count(); ++i)
@@ -515,8 +522,10 @@ void c2bReferenceList::scrollToReference(const QString& id)
 {
     if (id.isEmpty())
         return;
-    QList<QTreeWidgetItem*> items = ui.listView->findItems(id, Qt::MatchExactly, 1);
-    QTreeWidgetItem* item = items.at(0);
+    QList<QTreeWidgetItem*> items(ui.listView->findItems(id, Qt::MatchExactly, 1));
+    if (items.count() == 0)
+        return;
+    QTreeWidgetItem* item(items.at(0));
     ui.listView->setFocus();
     item->setSelected(!item->isSelected());
     ui.listView->scrollToItem(item);
