@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bSaveRegExp.h"
@@ -43,7 +43,7 @@ journal volume pages year title author abstract
   Information about the basics on the editing and working with Regular
   Expressions as used by cb2Bib can be found at the Qt document file
 \htmlonly
-<a href="http://doc.qt.io/qt-5.6/QRegExp.html#introduction"
+<a href="https://doc.qt.io/archives/qt-5.6/QRegExp.html#introduction"
 target="_blank">Qt Documentation's QRegExp Class</a>.
 \endhtmlonly
 
