@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bSearchInFiles.h"
@@ -11,8 +11,7 @@
 
 #include <bibSearcher.h>
 
-#include <QFileInfo>
-#include <QTime>
+#include <time.h>
 
 
 c2bSearchInFiles::c2bSearchInFiles(const QString& file, QWidget* parentw) : QDialog(parentw)
@@ -138,10 +137,12 @@ void c2bSearchInFiles::searchB_clicked()
     if (searcher.patternsCount() == 0)
         return;
 
-    QTime t;
-    t.start();
+    const unsigned long start_time(clock());
+
     searcher.exec();
 
+    const double time(double(clock() - start_time) / double(CLOCKS_PER_SEC));
+
     QString search_status;
     if (searcher.hitsCount() > 0 || searcher.errorsCount() > 0)
     {
@@ -149,7 +150,7 @@ void c2bSearchInFiles::searchB_clicked()
             search_status = tr("Found %1 hits from %2 references (%3s)")
                             .arg(searcher.hitsCount())
                             .arg(searcher.referencesCount())
-                            .arg(t.elapsed() / 1000.0);
+                            .arg(time, 0, 'g', 3);
         else
             ui.searchLog->setText(_search_log);
         QApplication::processEvents();
@@ -158,7 +159,7 @@ void c2bSearchInFiles::searchB_clicked()
     else if (searcher.errorsCount() < 0)
         search_status = tr("Search aborted");
     else
-        search_status = tr("No reference found (%1s)").arg(t.elapsed() / 1000.0);
+        search_status = tr("No reference found (%1s)").arg(time, 0, 'g', 3);
     if (!search_status.isEmpty())
     {
         ui.searchLog->setText(search_status);
