@@ -1,23 +1,25 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #define C2B_CHECK_CAPITALIZATION 0
 #define C2B_CHECK_CODE_DECOMPOSITION 0
 #define C2B_CHECK_JOURNALS 0
 #define C2B_CHECK_PATTERNS 0
+#define C2B_CHECK_PDF_AUTHORS 0
 #define C2B_CHECK_PDF_CODES 0
 #include "c2bTests.h"
 
-#include <authorString.h>
 #include <bibParser.h>
 #include <document.h>
 #include <settings.h>
+#include <txtmatcher.h>
 
 #include <QCoreApplication>
 #include <QDataStream>
+#include <QSysInfo>
 #include <QTextStream>
 
 
@@ -66,6 +68,12 @@ int c2bTests::allTests()
     return 0;
 }
 
+int c2bTests::writeInformation()
+{
+    write_information();
+    return 0;
+}
+
 void c2bTests::compression_check()
 {
     QString test;
@@ -86,30 +94,35 @@ void c2bTests::compression_check()
     cout << endl;
     if (passed)
     {
-        cout << "-------------------------" << endl;
-        cout << "Check for c2b utf8 passed" << endl;
+        cout << "-----------------------------------------------------------------" << endl;
+        cout << "Check for c2b utf8: passed" << endl;
+        cout << "-----------------------------------------------------------------" << endl;
     }
     else
     {
-        cout << "-------------------------------------------------------------" << endl;
+        cout << "-----------------------------------------------------------------" << endl;
         cout << "WARNING: Check for c2b utf8 FAILED! Please report it as a bug" << endl;
+        cout << "-----------------------------------------------------------------" << endl;
         ++_failed_test_count;
     }
     ++_test_count;
 
-    ba += "--------------------------------------";
-    QByteArray cba(c2bUtils::compress(ba));
-    QByteArray uba(c2bUtils::uncompress(cba));
-    passed = ba == uba && ba.length() > cba.length();
+    test += "-----------------------------------------------------------------";
+    test += "=================================================================";
+    QByteArray cba(c2bUtils::compressString(test));
+    QString dcs(c2bUtils::decompressString(cba));
+    passed = (dcs == test) && (test.toUtf8().length() > cba.length()) && (dcs.utf16()[dcs.size()] == 0);
     if (passed)
     {
-        cout << "Check for zlib/lzo passed" << endl;
-        cout << "-------------------------" << endl;
+        cout << "-----------------------------------------------------------------" << endl;
+        cout << "Check for compression: passed" << endl;
+        cout << "-----------------------------------------------------------------" << endl;
     }
     else
     {
-        cout << "WARNING: Check for zlib/lzo FAILED! Please report it as a bug" << endl;
-        cout << "-------------------------------------------------------------" << endl;
+        cout << "-----------------------------------------------------------------" << endl;
+        cout << "WARNING: Check for compression FAILED! Please report it as a bug" << endl;
+        cout << "-----------------------------------------------------------------" << endl;
         ++_failed_test_count;
     }
     ++_test_count;
@@ -123,16 +136,29 @@ void c2bTests::write_information()
     cout << "-------------------------" << endl;
     cout << endl;
     cout << "Version: cb2bib " << C2B_VERSION << endl;
-#ifdef C2B_USE_LZO
+#if defined(C2B_USE_LZSSE)
+    cout << "Compression: lzsse" << endl;
+#elif defined(C2B_USE_LZ4)
+    cout << "Compression: lz4" << endl;
+#elif defined(C2B_USE_LZO)
     cout << "Compression: lzo2" << endl;
 #else
     cout << "Compression: zlib" << endl;
 #endif
-#if QT_VERSION >= 0x050400
+#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
     cout << "Optimized PCRE: yes" << endl;
 #else
     cout << "Optimized PCRE: no" << endl;
 #endif
+#ifdef C2B_USE_TXTMATCHER_AVX2
+    cout << "Optimized txtmatcher: AVX2" << endl;
+#endif
+#ifdef C2B_USE_TXTMATCHER_SSE2
+    cout << "Optimized txtmatcher: SSE2" << endl;
+#endif
+#ifdef C2B_USE_TXTMATCHER_SCALAR
+    cout << "Optimized txtmatcher: no" << endl;
+#endif
 #ifdef C2B_USE_QWEBKIT
     cout << "Compiled against QtWebKit: yes" << endl;
 #else
@@ -158,6 +184,16 @@ void c2bTests::write_information()
         C2B_DATA_DIR_MAC = QDir::cleanPath(QCoreApplication::instance()->applicationDirPath() + "/../Resources/");
     cout << "Application macosx data path: " << C2B_DATA_DIR_MAC << endl;
 #endif
+    cout << "\n-------------------------" << endl;
+    cout << "OS:" << endl;
+    cout << "Build CPU:       " << QSysInfo::buildCpuArchitecture() << endl;
+    cout << "CPU:             " << QSysInfo::currentCpuArchitecture() << endl;
+    cout << "Kernel Type:     " << QSysInfo::kernelType() << endl;
+    cout << "Kernel Version:  " << QSysInfo::kernelVersion() << endl;
+    cout << "Product Type:    " << QSysInfo::productType() << endl;
+    cout << "Product Version: " << QSysInfo::productVersion() << '|' << int(QSysInfo::productVersion().toDouble()) << endl;
+    cout << "Name:            " << QSysInfo::prettyProductName() << endl;
+    cout << "-------------------------" << endl;
     cout << endl;
 }
 
@@ -252,7 +288,7 @@ void c2bTests::heuristic_author()
     cout << "\nTotal characters: " << char_count << endl;
     return;
 #endif
-
+#if C2B_CHECK_PDF_AUTHORS
     cout << endl;
     cout << "----------------------------------------" << endl;
     cout << "Test heuristic author recognition on PDF" << endl;
@@ -360,6 +396,7 @@ void c2bTests::heuristic_author()
     cout << "Succeded: " << n_pdf - n_failed_pdf << endl;
     _test_count += n_pdf;
     _failed_test_count += n_failed_pdf;
+#endif
 }
 
 void c2bTests::check_abbreviations_txt()
@@ -635,7 +672,7 @@ void c2bTests::heuristic_journal()
     _test_count += n_pdf;
     _failed_test_count += n_failed_pdf;
 
-    qSort(doclengths);
+    std::sort(doclengths.begin(), doclengths.end());
     cout << "doclengths min max median: " << doclengths.first() << ' ' << doclengths.last() << ' '
          << doclengths.at(doclengths.count() / 2) << endl;
 #endif
@@ -675,9 +712,9 @@ void c2bTests::author_parser()
     author = "B. B. Aaaaaaa";
     input = "Aaaaaaa, BB";
     check_test(author == bp.parse("author", input), input, author);
-    author = "J. R. Aaaaaaa";
-    //    input = "Aaaaaaa, JR"; // Gives wrong processing of the initials JR
-    //    check_test(author == bp.parse("author", input), input, author);
+    // author = "J. R. Aaaaaaa";
+    // input = "Aaaaaaa, JR"; // Gives wrong processing of the initials JR (set to Jr)
+    // check_test(author == bp.parse("author", input), input, author);
 
     author = "J. Pi";
     input = "Joan Pi";
@@ -759,28 +796,28 @@ void c2bTests::author_parser()
     check_test(author == bp.parse("author", input), input, author);
     input = "Maggi III CL";
     check_test(author == bp.parse("author", input), input, author);
-    check_test(author == bp.parse("author", author::fromMedline(input)), input, author);
+    check_test(author == bp.parse("author", bp.authorFromMedline(input)), input, author);
     input = "Maggi, Carla L 3rd";
-    check_test(author == bp.parse("author", author::fromMedline(input)), input, author);
+    check_test(author == bp.parse("author", bp.authorFromMedline(input)), input, author);
     input = "Maggi CL 3rd";
-    check_test(author == bp.parse("author", author::fromMedline(input)), input, author);
+    check_test(author == bp.parse("author", bp.authorFromMedline(input)), input, author);
     author = "A. M. C. Lourtau";
     input = "Carr Lourtau, A M";
     check_test(author == bp.parse("author", input), input, author);
-    check_test(author == bp.parse("author", author::fromMedline(input)), input, author);
+    check_test(author == bp.parse("author", bp.authorFromMedline(input)), input, author);
     input = "Carr Lourtau, AM";
     check_test(author == bp.parse("author", input), input, author);
-    input = "Carr Lourtau AM"; // Gives 'L. A. Carr' (rare AU formatting)
-    //    check_test(author == bp.parse("author", author::fromMedline(input)), input, author);
+    // input = "Carr Lourtau AM"; // Gives 'L. A. Carr' (rare AU formatting)
+    // check_test(author == bp.parse("author", author::fromMedline(input)), input, author);
 
     author = "B. de Rivas";
     input = "de Rivas, Beatriz";
-    check_test(author == bp.parse("author", author::fromMedline(input)), input, author);
+    check_test(author == bp.parse("author", bp.authorFromMedline(input)), input, author);
     input = "de Rivas B";
-    check_test(author == bp.parse("author", author::fromMedline(input)), input, author);
+    check_test(author == bp.parse("author", bp.authorFromMedline(input)), input, author);
     author = "B. De Baets";
     input = "  De Baets, B  ";
-    check_test(author == bp.parse("author", author::fromMedline(input)), input, author);
+    check_test(author == bp.parse("author", bp.authorFromMedline(input)), input, author);
 }
 
 void c2bTests::heuristic_pvny()
