@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BTESTS_H
@@ -25,6 +25,7 @@ public:
     ~c2bTests();
 
     int allTests();
+    int writeInformation();
 
 
 private:
@@ -47,7 +48,7 @@ private:
 
     static QString decomposition(const QChar& c);
 
-    inline static const char* boolToStr(bool b)
+    static inline const char* boolToStr(bool b)
     {
         if (b)
             return "passed";
