@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bTextEdit.h"
@@ -192,13 +192,17 @@ void c2bTextEdit::loadSettings()
 int c2bTextEdit::lineNumberAreaWidth()
 {
     int digits(1);
-    int max(qMax(1, blockCount()));
-    while (max >= 10)
+    int dmax(std::max(1, blockCount()));
+    while (dmax >= 10)
     {
-        max /= 10;
+        dmax /= 10;
         ++digits;
     }
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+    const int space(5 + fontMetrics().horizontalAdvance(QLatin1Char('9')) * digits);
+#else
     const int space(5 + fontMetrics().width(QLatin1Char('9')) * digits);
+#endif
     return space;
 }
 
@@ -230,7 +234,7 @@ void c2bTextEdit::lineNumberAreaPaintEvent(QPaintEvent* qevent)
     painter.fillRect(qevent->rect(), _line_number_area_color);
     painter.setPen(*_line_number_color_p);
     QFont f = font();
-    f.setPointSize(qMax(0, f.pointSize() - 3));
+    f.setPointSize(std::max(0, f.pointSize() - 3));
     painter.setFont(f);
 
     QTextBlock block = firstVisibleBlock();
