@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bUpdateMetadata.h"
@@ -90,7 +90,8 @@ void c2bUpdateMetadata::update()
         }
         ++doc_counter;
         bibReference mref;
-        if (mp->metadata(file, &mref))
+        const bool has_reference(mp->metadata(file, &mref));
+        if (has_reference)
             if (!needsUpdating(ref, mref))
                 continue;
         if (!fi.isWritable())
@@ -100,7 +101,7 @@ void c2bUpdateMetadata::update()
             continue;
         }
         QString error_str;
-        if (mp->insertMetadata(ref, file, &error_str))
+        if (mp->insertMetadata(ref, file, &error_str, has_reference))
         {
             if (mp->metadata(file, &mref))
                 if (!needsUpdating(ref, mref))
