@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *   findDialog was originally adapted from Qt Designer
  *   Copyright (C) 2001 Trolltech AS.  All rights reserved.
@@ -135,14 +135,13 @@ bool findDialog::findText(const QString& pattern, bool do_forward, bool do_case_
 
     if (c.hasSelection())
         c.setPosition(do_forward ? c.position() : c.anchor(), QTextCursor::MoveAnchor);
-    QTextCursor newCursor = c;
     if (!do_forward)
         options |= QTextDocument::FindBackward;
     if (m_find_case)
         options |= QTextDocument::FindCaseSensitively;
     if (m_find_words)
         options |= QTextDocument::FindWholeWords;
-    newCursor = doc->find(m_find_pattern, c, options);
+    QTextCursor newCursor(doc->find(m_find_pattern, c, options));
     bool found(true);
     if (newCursor.isNull())
     {
@@ -155,12 +154,14 @@ bool findDialog::findText(const QString& pattern, bool do_forward, bool do_case_
             found = false;
         }
     }
+    if (!found)
+        return false;
     if (_editor->inherits("QPlainTextEdit"))
     {
         QPlainTextEdit* ed = qobject_cast<QPlainTextEdit*>(_editor);
         ed->setTextCursor(newCursor);
         ed->verticalScrollBar()->setValue(ed->verticalScrollBar()->maximum());
-        ed->ensureCursorVisible();
+        ed->centerCursor();
     }
     else if (_editor->inherits("QTextEdit"))
     {
@@ -168,6 +169,8 @@ bool findDialog::findText(const QString& pattern, bool do_forward, bool do_case_
         ed->setTextCursor(newCursor);
         ed->verticalScrollBar()->setValue(ed->verticalScrollBar()->maximum());
         ed->ensureCursorVisible();
+        ed->verticalScrollBar()->setValue(ed->verticalScrollBar()->value() - ed->viewport()->height() / 3);
+        ed->ensureCursorVisible();
     }
     return found;
 }
