@@ -1,12 +1,13 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Pere Constans
+ *   Copyright (C) 2004-2021 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "WinConsole.h"
 
 #include <QEventLoop>
+#include <QSysInfo>
 
 #include <fcntl.h>
 #include <io.h>
@@ -15,8 +16,20 @@
 
 WinConsole::WinConsole(QObject* parento) : QObject(parento)
 {
-    // Remove _setmode on older Windows consoles
-    _setmode(_fileno(stdout), _O_U16TEXT);
+    // Exclude _setmode on older Windows consoles
+    if (int(QSysInfo::productVersion().toDouble()) > 7)
+    {
+        try
+        {
+            fflush(stdout);
+            _setmode(_fileno(stdout), _O_U16TEXT);
+        }
+        catch (...)
+        {
+            fflush(stdout);
+            _setmode(_fileno(stdout), _O_TEXT);
+        }
+    }
 }
 
 WinConsole::~WinConsole() {}
